@@ -22,10 +22,10 @@ def register_types(module):
     register_types_ns3_Config(nested_module)
     
     
-    ## Register a nested module for the namespace TimeStepPrecision
+    ## Register a nested module for the namespace FatalImpl
     
-    nested_module = module.add_cpp_namespace('TimeStepPrecision')
-    register_types_ns3_TimeStepPrecision(nested_module)
+    nested_module = module.add_cpp_namespace('FatalImpl')
+    register_types_ns3_FatalImpl(nested_module)
     
     
     ## Register a nested module for the namespace addressUtils
@@ -68,7 +68,7 @@ def register_types_ns3_Config(module):
     root_module = module.get_root()
     
 
-def register_types_ns3_TimeStepPrecision(module):
+def register_types_ns3_FatalImpl(module):
     root_module = module.get_root()
     
 
@@ -630,7 +630,7 @@ def register_Ns3Ipv6StaticRouting_methods(root_module, cls):
 def register_functions(root_module):
     module = root_module
     register_functions_ns3_Config(module.get_submodule('Config'), root_module)
-    register_functions_ns3_TimeStepPrecision(module.get_submodule('TimeStepPrecision'), root_module)
+    register_functions_ns3_FatalImpl(module.get_submodule('FatalImpl'), root_module)
     register_functions_ns3_addressUtils(module.get_submodule('addressUtils'), root_module)
     register_functions_ns3_aodv(module.get_submodule('aodv'), root_module)
     register_functions_ns3_dot11s(module.get_submodule('dot11s'), root_module)
@@ -642,7 +642,7 @@ def register_functions(root_module):
 def register_functions_ns3_Config(module, root_module):
     return
 
-def register_functions_ns3_TimeStepPrecision(module, root_module):
+def register_functions_ns3_FatalImpl(module, root_module):
     return
 
 def register_functions_ns3_addressUtils(module, root_module):
