@@ -20,24 +20,13 @@
 #include "buffer.h"
 #include "ns3/assert.h"
 #include "ns3/log.h"
-#include "ns3/fatal-error.h"
-#include "ns3/test.h"
-#include "ns3/random-variable.h"
-#include <iomanip>
-#include <iostream>
 
 NS_LOG_COMPONENT_DEFINE ("Buffer");
 
 #define LOG_INTERNAL_STATE(y)                                                                    \
-NS_LOG_LOGIC (y << "start="<<m_start<<", end="<<m_end<<", zero start="<<m_zeroAreaStart<<              \
-          ", zero end="<<m_zeroAreaEnd<<", count="<<m_data->m_count<<", size="<<m_data->m_size<<   \
-          ", dirty start="<<m_data->m_dirtyStart<<", dirty end="<<m_data->m_dirtyEnd)
-
-#ifdef BUFFER_HEURISTICS
-#define HEURISTICS(x) x
-#else
-#define HEURISTICS(x)
-#endif
+  NS_LOG_LOGIC (y << "start="<<m_start<<", end="<<m_end<<", zero start="<<m_zeroAreaStart<<              \
+                ", zero end="<<m_zeroAreaEnd<<", count="<<m_data->m_count<<", size="<<m_data->m_size<<   \
+                ", dirty start="<<m_data->m_dirtyStart<<", dirty end="<<m_data->m_dirtyEnd)
 
 namespace {
 
@@ -54,57 +43,11 @@ static struct Zeroes
 
 }
 
-//#define PRINT_STATS 1
-
 namespace ns3 {
 
-/**
- * This data structure is variable-sized through its last member whose size
- * is determined at allocation time and stored in the m_size field.
- *
- * The so-called "dirty area" describes the area in the buffer which
- * has been reserved and used by a user. Multiple Buffer instances
- * may reference the same BufferData object instance and may
- * reference different parts of the underlying byte buffer. The
- * "dirty area" is union of all the areas referenced by the Buffer
- * instances which reference the same BufferData instance.
- * New user data can be safely written only outside of the "dirty
- * area" if the reference count is higher than 1 (that is, if
- * more than one Buffer instance references the same BufferData).
- */
-struct BufferData {
-  /* The reference count of an instance of this data structure.
-   * Each buffer which references an instance holds a count.
-   */
-  uint32_t m_count;
-  /* the size of the m_data field below.
-   */
-  uint32_t m_size;
-  /* offset from the start of the m_data field below to the
-   * start of the area in which user bytes were written.
-   */
-  uint32_t m_dirtyStart;
-  /* offset from the start of the m_data field below to the
-   * end of the area in which user bytes were written.
-   */
-  uint32_t m_dirtyEnd;
-  /* The real data buffer holds _at least_ one byte.
-   * Its real size is stored in the m_size field.
-   */
-  uint8_t m_data[1];
-};
-typedef std::vector<struct BufferData*> BufferDataList;
 
-static struct BufferData *BufferAllocate (uint32_t reqSize);
-
-static void BufferDeallocate (struct BufferData *data);
-
-
-} // namespace ns3
-
-namespace ns3 {
-
-#ifdef BUFFER_HEURISTICS
+uint32_t Buffer::g_recommendedStart = 0;
+#ifdef BUFFER_FREE_LIST
 /* The following macros are pretty evil but they are needed to allow us to
  * keep track of 3 possible states for the g_freeList variable:
  *  - uninitialized means that no one has created a buffer yet
@@ -123,78 +66,31 @@ namespace ns3 {
  * constructor orderings.
  */
 #define MAGIC_DESTROYED (~(long) 0)
-#define IS_UNINITIALIZED(x) (x == (BufferDataList*)0)
-#define IS_DESTROYED(x) (x == (BufferDataList*)MAGIC_DESTROYED)
+#define IS_UNINITIALIZED(x) (x == (Buffer::FreeList*)0)
+#define IS_DESTROYED(x) (x == (Buffer::FreeList*)MAGIC_DESTROYED)
 #define IS_INITIALIZED(x) (!IS_UNINITIALIZED(x) && !IS_DESTROYED(x))
-#define DESTROYED ((BufferDataList*)MAGIC_DESTROYED)
-#define UNINITIALIZED ((BufferDataList*)0)
-static uint32_t g_recommendedStart = 0;
-static uint64_t g_nAddNoRealloc = 0;
-static uint64_t g_nAddRealloc = 0;
-static BufferDataList *g_freeList = 0;
-static uint32_t g_maxSize = 0;
-static uint64_t g_nAllocs = 0;
-static uint64_t g_nCreates = 0;
-#endif /* BUFFER_HEURISTICS */
+#define DESTROYED ((Buffer::FreeList*)MAGIC_DESTROYED)
+#define UNINITIALIZED ((Buffer::FreeList*)0)
+uint32_t Buffer::g_maxSize = 0;
+Buffer::FreeList *Buffer::g_freeList = 0;
+struct Buffer::LocalStaticDestructor Buffer::g_localStaticDestructor;
 
-static struct LocalStaticDestructor {
-  ~LocalStaticDestructor(void)
-  {
-#ifdef PRINT_STATS
-#ifdef BUFFER_HEURISTICS
-    double efficiency;
-    efficiency = g_nAllocs;
-    efficiency /= g_nCreates;
-    std::cout <<"buffer free list efficiency="<<efficiency<<" (lower is better)" << std::endl;
-    std::cout <<"buffer free list max size="<<g_maxSize<<std::endl;
-    std::cout <<"buffer free list recommended start="<<g_recommendedStart<<std::endl;
-    double addEfficiency;
-    addEfficiency = g_nAddRealloc;
-    addEfficiency /= g_nAddNoRealloc;
-    std::cout <<"buffer add efficiency=" << addEfficiency << " (lower is better)"<<std::endl;
-    //std::cout <<"n add reallocs="<< g_nAddRealloc << std::endl;
-    //std::cout <<"n add no reallocs="<< g_nAddNoRealloc << std::endl;
-#endif /* BUFFER_HEURISTICS */
-#endif /* PRINT_STATS */
-    if (IS_INITIALIZED(g_freeList))
-      {
-        for (BufferDataList::iterator i = g_freeList->begin ();
-             i != g_freeList->end (); i++)
-          {
-            BufferDeallocate (*i);
-          }
-        delete g_freeList;
-        g_freeList = DESTROYED;
-      }
-  }
-} g_localStaticDestructor;
-
-struct BufferData *
-BufferAllocate (uint32_t reqSize)
+Buffer::LocalStaticDestructor::~LocalStaticDestructor(void)
 {
-  if (reqSize == 0) 
+  if (IS_INITIALIZED(g_freeList))
     {
-      reqSize = 1;
+      for (Buffer::FreeList::iterator i = g_freeList->begin ();
+           i != g_freeList->end (); i++)
+        {
+          Buffer::Deallocate (*i);
+        }
+      delete g_freeList;
+      g_freeList = DESTROYED;
     }
-  NS_ASSERT (reqSize >= 1);
-  uint32_t size = reqSize - 1 + sizeof (struct BufferData);
-  uint8_t *b = new uint8_t [size];
-  struct BufferData *data = reinterpret_cast<struct BufferData*>(b);
-  data->m_size = reqSize;
-  data->m_count = 1;
-  return data;
 }
 
 void
-BufferDeallocate (struct BufferData *data)
-{
-  NS_ASSERT (data->m_count == 0);
-  uint8_t *buf = reinterpret_cast<uint8_t *> (data);
-  delete [] buf;
-}
-#ifdef BUFFER_HEURISTICS
-void
-Buffer::Recycle (struct BufferData *data)
+Buffer::Recycle (struct Buffer::Data *data)
 {
   NS_ASSERT (data->m_count == 0);
   NS_ASSERT (!IS_UNINITIALIZED(g_freeList));
@@ -204,7 +100,7 @@ Buffer::Recycle (struct BufferData *data)
       IS_DESTROYED(g_freeList) ||
       g_freeList->size () > 1000)
     {
-      BufferDeallocate (data);
+      Buffer::Deallocate (data);
     }
   else
     {
@@ -213,48 +109,70 @@ Buffer::Recycle (struct BufferData *data)
     }
 }
 
-BufferData *
+Buffer::Data *
 Buffer::Create (uint32_t dataSize)
 {
   /* try to find a buffer correctly sized. */
-  g_nCreates++;
   if (IS_UNINITIALIZED(g_freeList))
     {
-      g_freeList = new BufferDataList ();
+      g_freeList = new Buffer::FreeList ();
     }
   else if (IS_INITIALIZED(g_freeList))
     {
       while (!g_freeList->empty ()) 
         {
-          struct BufferData *data = g_freeList->back ();
+          struct Buffer::Data *data = g_freeList->back ();
           g_freeList->pop_back ();
           if (data->m_size >= dataSize) 
             {
               data->m_count = 1;
               return data;
             }
-          BufferDeallocate (data);
+          Buffer::Deallocate (data);
         }
     }
-  g_nAllocs++;
-  struct BufferData *data = BufferAllocate (dataSize);
+  struct Buffer::Data *data = Buffer::Allocate (dataSize);
   NS_ASSERT (data->m_count == 1);
   return data;
 }
-#else
+#else /* BUFFER_FREE_LIST */
 void
-Buffer::Recycle (struct BufferData *data)
+Buffer::Recycle (struct Buffer::Data *data)
 {
   NS_ASSERT (data->m_count == 0);
-  BufferDeallocate (data);
+  Deallocate (data);
 }
 
-BufferData *
+Buffer::Data *
 Buffer::Create (uint32_t size)
 {
-  return BufferAllocate (size);
+  return Allocate (size);
+}
+#endif /* BUFFER_FREE_LIST */
+
+struct Buffer::Data *
+Buffer::Allocate (uint32_t reqSize)
+{
+  if (reqSize == 0) 
+    {
+      reqSize = 1;
+    }
+  NS_ASSERT (reqSize >= 1);
+  uint32_t size = reqSize - 1 + sizeof (struct Buffer::Data);
+  uint8_t *b = new uint8_t [size];
+  struct Buffer::Data *data = reinterpret_cast<struct Buffer::Data*>(b);
+  data->m_size = reqSize;
+  data->m_count = 1;
+  return data;
+}
+
+void
+Buffer::Deallocate (struct Buffer::Data *data)
+{
+  NS_ASSERT (data->m_count == 0);
+  uint8_t *buf = reinterpret_cast<uint8_t *> (data);
+  delete [] buf;
 }
-#endif
 
 Buffer::Buffer ()
 {
@@ -300,9 +218,9 @@ Buffer::CheckInternalState (void) const
   if (!ok)
     {
       LOG_INTERNAL_STATE ("check " << this << 
-                          ", " << (offsetsOk?"true":"false") << 
-                          ", " << (dirtyOk?"true":"false") << 
-                          ", " << (internalSizeOk?"true":"false") << " ");
+                          ", " << (offsetsOk ? "true" : "false") <<
+                          ", " << (dirtyOk ? "true" : "false") <<
+                          ", " << (internalSizeOk ? "true" : "false") << " ");
     }
   return ok;
 #else
@@ -315,12 +233,8 @@ Buffer::Initialize (uint32_t zeroSize)
 {
   NS_LOG_FUNCTION (this << zeroSize);
   m_data = Buffer::Create (0);
-#ifdef BUFFER_HEURISTICS
   m_start = std::min (m_data->m_size, g_recommendedStart);
   m_maxZeroAreaStart = m_start;
-#else
-  m_start = 0;
-#endif /* BUFFER_HEURISTICS */
   m_zeroAreaStart = m_start;
   m_zeroAreaEnd = m_zeroAreaStart + zeroSize;
   m_end = m_zeroAreaEnd;
@@ -329,21 +243,6 @@ Buffer::Initialize (uint32_t zeroSize)
   NS_ASSERT (CheckInternalState ());
 }
 
-Buffer::Buffer (Buffer const&o)
-  : m_data (o.m_data),
-#ifdef BUFFER_HEURISTICS
-    m_maxZeroAreaStart (o.m_zeroAreaStart),
-#endif
-    m_zeroAreaStart (o.m_zeroAreaStart),
-    m_zeroAreaEnd (o.m_zeroAreaEnd),
-    m_start (o.m_start),
-    m_end (o.m_end)
-{
-  NS_LOG_FUNCTION (this << &o);
-  m_data->m_count++;
-  NS_ASSERT (CheckInternalState ());
-}
-
 Buffer &
 Buffer::operator = (Buffer const&o)
 {
@@ -360,10 +259,8 @@ Buffer::operator = (Buffer const&o)
       m_data = o.m_data;
       m_data->m_count++;
     }
-  HEURISTICS (
   g_recommendedStart = std::max (g_recommendedStart, m_maxZeroAreaStart);
   m_maxZeroAreaStart = o.m_maxZeroAreaStart;
-  );
   m_zeroAreaStart = o.m_zeroAreaStart;
   m_zeroAreaEnd = o.m_zeroAreaEnd;
   m_start = o.m_start;
@@ -376,7 +273,7 @@ Buffer::~Buffer ()
 {
   NS_LOG_FUNCTION (this);
   NS_ASSERT (CheckInternalState ());
-  HEURISTICS (g_recommendedStart = std::max (g_recommendedStart, m_maxZeroAreaStart));
+  g_recommendedStart = std::max (g_recommendedStart, m_maxZeroAreaStart);
   m_data->m_count--;
   if (m_data->m_count == 0) 
     {
@@ -384,19 +281,6 @@ Buffer::~Buffer ()
     }
 }
 
-Buffer::Iterator 
-Buffer::Begin (void) const
-{
-  NS_ASSERT (CheckInternalState ());
-  return Buffer::Iterator (this);
-}
-Buffer::Iterator 
-Buffer::End (void) const
-{
-  NS_ASSERT (CheckInternalState ());
-  return Buffer::Iterator (this, false);
-}
-
 uint32_t
 Buffer::GetInternalSize (void) const
 {
@@ -427,12 +311,11 @@ Buffer::AddAtStart (uint32_t start)
       dirty = m_start > m_data->m_dirtyStart;
       // update dirty area
       m_data->m_dirtyStart = m_start;
-      HEURISTICS (g_nAddNoRealloc++);
     } 
   else
     {
       uint32_t newSize = GetInternalSize () + start;
-      struct BufferData *newData = Buffer::Create (newSize);
+      struct Buffer::Data *newData = Buffer::Create (newSize);
       memcpy (newData->m_data + start, m_data->m_data + m_start, GetInternalSize ());
       m_data->m_count--;
       if (m_data->m_count == 0)
@@ -454,9 +337,8 @@ Buffer::AddAtStart (uint32_t start)
 
       dirty = true;
 
-      HEURISTICS (g_nAddRealloc++);
     }
-  HEURISTICS (m_maxZeroAreaStart = std::max (m_maxZeroAreaStart, m_zeroAreaStart));
+  m_maxZeroAreaStart = std::max (m_maxZeroAreaStart, m_zeroAreaStart);
   LOG_INTERNAL_STATE ("add start=" << start << ", ");
   NS_ASSERT (CheckInternalState ());
   return dirty;
@@ -482,12 +364,11 @@ Buffer::AddAtEnd (uint32_t end)
 
       dirty = m_end < m_data->m_dirtyEnd;
 
-      HEURISTICS (g_nAddNoRealloc++);
     } 
   else
     {
       uint32_t newSize = GetInternalSize () + end;
-      struct BufferData *newData = Buffer::Create (newSize);
+      struct Buffer::Data *newData = Buffer::Create (newSize);
       memcpy (newData->m_data, m_data->m_data + m_start, GetInternalSize ());
       m_data->m_count--;
       if (m_data->m_count == 0) 
@@ -509,9 +390,8 @@ Buffer::AddAtEnd (uint32_t end)
 
       dirty = true;
 
-      HEURISTICS (g_nAddRealloc++);
     } 
-  HEURISTICS (m_maxZeroAreaStart = std::max (m_maxZeroAreaStart, m_zeroAreaStart));
+  m_maxZeroAreaStart = std::max (m_maxZeroAreaStart, m_zeroAreaStart);
   LOG_INTERNAL_STATE ("add end=" << end << ", ");
   NS_ASSERT (CheckInternalState ());
 
@@ -600,7 +480,7 @@ Buffer::RemoveAtStart (uint32_t start)
       m_zeroAreaEnd = m_end;
       m_zeroAreaStart = m_end;
     }
-  HEURISTICS (m_maxZeroAreaStart = std::max (m_maxZeroAreaStart, m_zeroAreaStart));
+  m_maxZeroAreaStart = std::max (m_maxZeroAreaStart, m_zeroAreaStart);
   LOG_INTERNAL_STATE ("rem start=" << start << ", ");
   NS_ASSERT (CheckInternalState ());
 }
@@ -635,7 +515,7 @@ Buffer::RemoveAtEnd (uint32_t end)
       m_zeroAreaEnd = m_start;
       m_zeroAreaStart = m_start;
     }
-  HEURISTICS (m_maxZeroAreaStart = std::max (m_maxZeroAreaStart, m_zeroAreaStart));
+  m_maxZeroAreaStart = std::max (m_maxZeroAreaStart, m_zeroAreaStart);
   LOG_INTERNAL_STATE ("rem end=" << end << ", ");
   NS_ASSERT (CheckInternalState ());
 }
@@ -699,9 +579,9 @@ Buffer::GetSerializedSize (void) const
 uint32_t
 Buffer::Serialize (uint8_t* buffer, uint32_t maxSize) const
 {
-  uint32_t* p = (uint32_t*)buffer;
+  uint32_t* p = reinterpret_cast<uint32_t *> (buffer);
   uint32_t size = 0;
-  
+
   NS_LOG_FUNCTION (this);
 
   // Add the zero data length
@@ -768,9 +648,9 @@ Buffer::Serialize (uint8_t* buffer, uint32_t maxSize) const
 }
 
 uint32_t 
-Buffer::Deserialize (uint8_t *buffer, uint32_t size)
+Buffer::Deserialize (const uint8_t *buffer, uint32_t size)
 {
-  uint32_t* p = (uint32_t*)buffer;
+  const uint32_t* p = reinterpret_cast<const uint32_t *> (buffer);
   uint32_t sizeCheck = size-4;
 
   NS_ASSERT (sizeCheck >= 4);
@@ -779,7 +659,7 @@ Buffer::Deserialize (uint8_t *buffer, uint32_t size)
 
   // Create zero bytes
   Initialize (zeroDataLength);
-  
+
   // Add start data
   NS_ASSERT (sizeCheck >= 4);
   uint32_t dataStartLength = *p++;
@@ -787,8 +667,8 @@ Buffer::Deserialize (uint8_t *buffer, uint32_t size)
   AddAtStart (dataStartLength);
 
   NS_ASSERT (sizeCheck >= dataStartLength);
-  Begin ().Write ((uint8_t*)p, dataStartLength);
-  p += (((dataStartLength+3)&(~3))/4);
+  Begin ().Write (reinterpret_cast<uint8_t *> (const_cast<uint32_t *> (p)), dataStartLength);
+  p += (((dataStartLength+3)&(~3))/4); // Advance p, insuring 4 byte boundary
   sizeCheck -= ((dataStartLength+3)&(~3));
 
   // Add end data
@@ -800,10 +680,10 @@ Buffer::Deserialize (uint8_t *buffer, uint32_t size)
   NS_ASSERT (sizeCheck >= dataEndLength);
   Buffer::Iterator tmp = End ();
   tmp.Prev (dataEndLength);
-  tmp.Write ((uint8_t*)p, dataEndLength);
-  p += (((dataEndLength+3)&(~3))/4);
+  tmp.Write (reinterpret_cast<uint8_t *> (const_cast<uint32_t *> (p)), dataEndLength);
+  p += (((dataEndLength+3)&(~3))/4); // Advance p, insuring 4 byte boundary
   sizeCheck -= ((dataEndLength+3)&(~3));
-  
+
   NS_ASSERT (sizeCheck == 0);
   // return zero if buffer did not 
   // contain a complete message
@@ -906,59 +786,6 @@ Buffer::CopyData (uint8_t *buffer, uint32_t size) const
  ******************************************************/
 
 
-Buffer::Iterator::Iterator ()
-  : m_zeroStart (0),
-    m_zeroEnd (0),
-    m_dataStart (0),
-    m_dataEnd (0),
-    m_current (0),
-    m_data (0)
-{}
-Buffer::Iterator::Iterator (Buffer const*buffer)
-{
-  Construct (buffer);
-  m_current = m_dataStart;
-}
-Buffer::Iterator::Iterator (Buffer const*buffer, bool dummy)
-{
-  Construct (buffer);
-  m_current = m_dataEnd;
-}
-
-void
-Buffer::Iterator::Construct (const Buffer *buffer)
-{
-  m_zeroStart = buffer->m_zeroAreaStart;
-  m_zeroEnd = buffer->m_zeroAreaEnd;
-  m_dataStart = buffer->m_start;
-  m_dataEnd = buffer->m_end;
-  m_data = buffer->m_data->m_data;
-}
-
-void 
-Buffer::Iterator::Next (void)
-{
-  NS_ASSERT (m_current + 1 <= m_dataEnd);
-  m_current++;
-}
-void 
-Buffer::Iterator::Prev (void)
-{
-  NS_ASSERT (m_current >= 1);
-  m_current--;
-}
-void 
-Buffer::Iterator::Next (uint32_t delta)
-{
-  NS_ASSERT (m_current + delta <= m_dataEnd);
-  m_current += delta;
-}
-void 
-Buffer::Iterator::Prev (uint32_t delta)
-{
-  NS_ASSERT (m_current >= delta);
-  m_current -= delta;
-}
 uint32_t
 Buffer::Iterator::GetDistanceFrom (Iterator const &o) const
 {
@@ -1002,8 +829,8 @@ bool
 Buffer::Iterator::Check (uint32_t i) const
 {
   return i >= m_dataStart && 
-    !(i >= m_zeroStart && i < m_zeroEnd) &&
-    i <= m_dataEnd;
+         !(i >= m_zeroStart && i < m_zeroEnd) &&
+         i <= m_dataEnd;
 }
 
 
@@ -1017,7 +844,8 @@ Buffer::Iterator::Write (Iterator start, Iterator end)
   NS_ASSERT (m_data != start.m_data);
   uint32_t size = end.m_current - start.m_current;
   Iterator cur = start;
-  NS_ASSERT (CheckNoZero (m_current, m_current + size));
+  NS_ASSERT_MSG (CheckNoZero (m_current, m_current + size),
+                 GetWriteErrorMessage ());
   if (start.m_current <= start.m_zeroStart)
     {
       uint32_t toCopy = std::min (size, start.m_zeroStart - start.m_current);
@@ -1120,7 +948,8 @@ Buffer::Iterator::WriteHtonU64 (uint64_t data)
 void 
 Buffer::Iterator::Write (uint8_t const*buffer, uint32_t size)
 {
-  NS_ASSERT (CheckNoZero (m_current, size));
+  NS_ASSERT_MSG (CheckNoZero (m_current, size),
+                 GetWriteErrorMessage ());
   uint8_t *to;
   if (m_current <= m_zeroStart)
     {
@@ -1134,17 +963,6 @@ Buffer::Iterator::Write (uint8_t const*buffer, uint32_t size)
   m_current += size;
 }
 
-uint16_t 
-Buffer::Iterator::ReadU16 (void)
-{
-  uint8_t byte0 = ReadU8 ();
-  uint8_t byte1 = ReadU8 ();
-  uint16_t data = byte1;
-  data <<= 8;
-  data |= byte0;
-
-  return data;
-}
 uint32_t 
 Buffer::Iterator::ReadU32 (void)
 {
@@ -1313,7 +1131,7 @@ Buffer::Iterator::CalculateIpChecksum(uint16_t size, uint32_t initialChecksum)
     sum += ReadU16 ();
 
   if (size & 1)
-     sum += ReadU8 ();
+    sum += ReadU8 ();
 
   while (sum >> 16)
     sum = (sum & 0xffff) + (sum >> 16);
@@ -1326,335 +1144,47 @@ Buffer::Iterator::GetSize (void) const
   return m_dataEnd - m_dataStart;
 }
 
-//-----------------------------------------------------------------------------
-// Unit tests
-//-----------------------------------------------------------------------------
-class BufferTest: public TestCase {
-private:
-  bool EnsureWrittenBytes (Buffer b, uint32_t n, uint8_t array[]);
-public:
-  virtual bool DoRun (void);
-  BufferTest ();
-};
 
-
-BufferTest::BufferTest ()
-  : TestCase ("Buffer") {}
-
-bool
-BufferTest::EnsureWrittenBytes (Buffer b, uint32_t n, uint8_t array[])
+std::string 
+Buffer::Iterator::GetReadErrorMessage (void) const
 {
-  bool success = true;
-  uint8_t *expected = array;
-  uint8_t const*got;
-  got = b.PeekData ();
-  for (uint32_t j = 0; j < n; j++) 
+  std::string str = "You have attempted to read beyond the bounds of the "
+    "available buffer space. This usually indicates that a "
+    "Header::Deserialize or Trailer::Deserialize method "
+    "is trying to read data which was not written by "
+    "a Header::Serialize or Trailer::Serialize method. "
+    "In short: check the code of your Serialize and Deserialize "
+    "methods.";
+  return str;
+}
+std::string 
+Buffer::Iterator::GetWriteErrorMessage (void) const
+{
+  std::string str;
+  if (m_current < m_dataStart)
     {
-      if (got[j] != expected[j]) 
-        {
-          success = false;
-        }
+      str = "You have attempted to write before the start of the available "
+        "buffer space. This usually indicates that Trailer::GetSerializedSize "
+        "returned a size which is too small compared to what Trailer::Serialize "
+        "is actually using.";
     }
-  if (!success) 
+  else if (m_current >= m_dataEnd)
     {
-      std::ostringstream failure;
-      failure << "Buffer -- ";
-      failure << "expected: n=";
-      failure << n << ", ";
-      failure.setf (std::ios::hex, std::ios::basefield);
-      for (uint32_t j = 0; j < n; j++) 
-        {
-          failure << (uint16_t)expected[j] << " ";
-        }
-      failure.setf (std::ios::dec, std::ios::basefield);
-      failure << "got: ";
-      failure.setf (std::ios::hex, std::ios::basefield);
-      for (uint32_t j = 0; j < n; j++) 
-        {
-          failure << (uint16_t)got[j] << " ";
-        }
-      failure << std::endl;
-      ReportTestFailure ("", "", "", failure.str(), __FILE__, __LINE__);
+      str = "You have attempted to write after the end of the available "
+        "buffer space. This usually indicates that Header::GetSerializedSize "
+        "returned a size which is too small compared to what Header::Serialize "
+        "is actually using.";
     }
-  return success;
+  else
+    {
+      NS_ASSERT (m_current >= m_zeroStart && m_current < m_zeroEnd);
+      str = "You have attempted to write inside the payload area of the "
+        "buffer. This usually indicates that your Serialize method uses more "
+        "buffer space than what your GetSerialized method returned.";
+    }
+  return str;
 }
 
-/* Note: works only when variadic macros are
- * available which is the case for gcc.
- * XXX
- */
-#define ENSURE_WRITTEN_BYTES(buffer, n, ...)     \
-  {                                              \
-  uint8_t bytes[] = {__VA_ARGS__};             \
-  if (!EnsureWrittenBytes (buffer, n , bytes)) \
-    {                                          \
-      SetErrorStatus (false);                  \
-    }                                          \
-  }
-
-bool
-BufferTest::DoRun (void)
-{
-  Buffer buffer;
-  Buffer::Iterator i;
-  buffer.AddAtStart (6);
-  i = buffer.Begin ();
-  i.WriteU8 (0x66);
-  ENSURE_WRITTEN_BYTES (buffer, 1, 0x66);
-  i = buffer.Begin ();
-  i.WriteU8 (0x67);
-  ENSURE_WRITTEN_BYTES (buffer, 1, 0x67);
-  i.WriteHtonU16 (0x6568);
-  i = buffer.Begin ();
-  ENSURE_WRITTEN_BYTES (buffer, 3, 0x67, 0x65, 0x68);
-  i.WriteHtonU16 (0x6369);
-  ENSURE_WRITTEN_BYTES (buffer, 3, 0x63, 0x69, 0x68);
-  i.WriteHtonU32 (0xdeadbeaf);
-  ENSURE_WRITTEN_BYTES (buffer, 6, 0x63, 0x69, 0xde, 0xad, 0xbe, 0xaf);
-  buffer.AddAtStart (2);
-  i = buffer.Begin ();
-  i.WriteU16 (0);
-  ENSURE_WRITTEN_BYTES (buffer, 8, 0, 0, 0x63, 0x69, 0xde, 0xad, 0xbe, 0xaf);
-  buffer.AddAtEnd (2);
-  i = buffer.Begin ();
-  i.Next (8);
-  i.WriteU16 (0);
-  ENSURE_WRITTEN_BYTES (buffer, 10, 0, 0, 0x63, 0x69, 0xde, 0xad, 0xbe, 0xaf, 0, 0);
-  buffer.RemoveAtStart (3);
-  i = buffer.Begin ();
-  ENSURE_WRITTEN_BYTES (buffer, 7, 0x69, 0xde, 0xad, 0xbe, 0xaf, 0, 0);
-  buffer.RemoveAtEnd (4);
-  i = buffer.Begin ();
-  ENSURE_WRITTEN_BYTES (buffer, 3, 0x69, 0xde, 0xad);
-  buffer.AddAtStart (1);
-  i = buffer.Begin ();
-  i.WriteU8 (0xff);
-  ENSURE_WRITTEN_BYTES (buffer, 4, 0xff, 0x69, 0xde, 0xad);
-  buffer.AddAtEnd (1);
-  i = buffer.Begin ();
-  i.Next (4);
-  i.WriteU8 (0xff);
-  i.Prev (2);
-  uint16_t saved = i.ReadU16 ();
-  i.Prev (2);
-  i.WriteHtonU16 (0xff00);
-  i.Prev (2);
-  if (i.ReadNtohU16 () != 0xff00) 
-    {
-      SetErrorStatus (false);
-    }
-  i.Prev (2);
-  i.WriteU16 (saved);
-  ENSURE_WRITTEN_BYTES (buffer, 5, 0xff, 0x69, 0xde, 0xad, 0xff);
-  Buffer o = buffer;
-  ENSURE_WRITTEN_BYTES (o, 5, 0xff, 0x69, 0xde, 0xad, 0xff);
-  o.AddAtStart (1);
-  i = o.Begin ();
-  i.WriteU8 (0xfe);
-  ENSURE_WRITTEN_BYTES (o, 6, 0xfe, 0xff, 0x69, 0xde, 0xad, 0xff);
-  buffer.AddAtStart (2);
-  i = buffer.Begin ();
-  i.WriteU8 (0xfd);
-  i.WriteU8 (0xfd);
-  ENSURE_WRITTEN_BYTES (o, 6, 0xfe, 0xff, 0x69, 0xde, 0xad, 0xff);
-  ENSURE_WRITTEN_BYTES (buffer, 7, 0xfd, 0xfd, 0xff, 0x69, 0xde, 0xad, 0xff);
-
-  // test 64-bit read/write
-  Buffer buff64;
-  buff64.AddAtStart(8);
-  i = buff64.Begin();
-  i.WriteU64 (0x0123456789ABCDEFllu);
-  ENSURE_WRITTEN_BYTES (buff64, 8, 0xef, 0xcd, 0xab, 0x89, 0x67, 0x45, 0x23, 0x01);
-  i = buff64.Begin();
-  if (i.ReadLsbtohU64() != 0x0123456789abcdefllu)
-    {
-      SetErrorStatus (false);
-    }
-  i = buff64.Begin();
-  i.WriteHtolsbU64 (0x0123456789ABCDEFllu);
-  ENSURE_WRITTEN_BYTES (buff64, 8, 0xef, 0xcd, 0xab, 0x89, 0x67, 0x45, 0x23, 0x01);
-  i = buff64.Begin();
-  if (i.ReadLsbtohU64() != 0x0123456789abcdefllu)
-    {
-      SetErrorStatus (false);
-    }
-  i = buff64.Begin();
-  i.WriteHtonU64 (0x0123456789ABCDEFllu);
-  ENSURE_WRITTEN_BYTES (buff64, 8, 0x01, 0x23, 0x45, 0x67, 0x89, 0xab, 0xcd, 0xef);
-  i = buff64.Begin();
-  if (i.ReadNtohU64() != 0x0123456789abcdefllu)
-    {
-      SetErrorStatus (false);
-    }
-
-  // test self-assignment
-  {
-      Buffer a = o;
-      a = a;
-  }
-
-  // test Remove start.
-  buffer = Buffer (5);
-  ENSURE_WRITTEN_BYTES (buffer, 5, 0, 0, 0, 0, 0);
-  buffer.RemoveAtStart (1);
-  ENSURE_WRITTEN_BYTES (buffer, 4, 0, 0, 0, 0);
-  buffer.AddAtStart (1);
-  buffer.Begin ().WriteU8 (0xff);
-  ENSURE_WRITTEN_BYTES (buffer, 5, 0xff, 0, 0, 0, 0);
-  buffer.RemoveAtStart(3);
-  ENSURE_WRITTEN_BYTES (buffer, 2, 0, 0);
-  buffer.AddAtStart (4);
-  buffer.Begin ().WriteHtonU32 (0xdeadbeaf);
-  ENSURE_WRITTEN_BYTES (buffer, 6,  0xde, 0xad, 0xbe, 0xaf, 0, 0);
-  buffer.RemoveAtStart (2);
-  ENSURE_WRITTEN_BYTES (buffer, 4,  0xbe, 0xaf, 0, 0);
-  buffer.AddAtEnd (4);
-  i = buffer.Begin ();
-  i.Next (4);
-  i.WriteHtonU32 (0xdeadbeaf);
-  ENSURE_WRITTEN_BYTES (buffer, 8,  0xbe, 0xaf, 0, 0, 0xde, 0xad, 0xbe, 0xaf);
-  buffer.RemoveAtStart (5);
-  ENSURE_WRITTEN_BYTES (buffer, 3,  0xad, 0xbe, 0xaf);
-  // test Remove end
-  buffer = Buffer (5);
-  ENSURE_WRITTEN_BYTES (buffer, 5, 0, 0, 0, 0, 0);
-  buffer.RemoveAtEnd (1);
-  ENSURE_WRITTEN_BYTES (buffer, 4, 0, 0, 0, 0);
-  buffer.AddAtEnd (2);
-  i = buffer.Begin ();
-  i.Next (4);
-  i.WriteU8 (0xab);
-  i.WriteU8 (0xac);
-  ENSURE_WRITTEN_BYTES (buffer, 6, 0, 0, 0, 0, 0xab, 0xac);
-  buffer.RemoveAtEnd (1);
-  ENSURE_WRITTEN_BYTES (buffer, 5, 0, 0, 0, 0, 0xab);
-  buffer.RemoveAtEnd (3);
-  ENSURE_WRITTEN_BYTES (buffer, 2, 0, 0);
-  buffer.AddAtEnd (6);
-  i = buffer.Begin ();
-  i.Next (2);
-  i.WriteU8 (0xac);
-  i.WriteU8 (0xad);
-  i.WriteU8 (0xae);
-  i.WriteU8 (0xaf);
-  i.WriteU8 (0xba);
-  i.WriteU8 (0xbb);
-  ENSURE_WRITTEN_BYTES (buffer, 8, 0, 0, 0xac, 0xad, 0xae, 0xaf, 0xba, 0xbb);
-  buffer.AddAtStart (3);
-  i = buffer.Begin ();
-  i.WriteU8 (0x30);
-  i.WriteU8 (0x31);
-  i.WriteU8 (0x32);
-  ENSURE_WRITTEN_BYTES (buffer, 11, 0x30, 0x31, 0x32, 0, 0, 0xac, 0xad, 0xae, 0xaf, 0xba, 0xbb);
-  buffer.RemoveAtEnd (9);
-  ENSURE_WRITTEN_BYTES (buffer, 2, 0x30, 0x31);
-  buffer = Buffer (3);
-  buffer.AddAtEnd (2);
-  i = buffer.Begin ();
-  i.Next (3);
-  i.WriteHtonU16 (0xabcd);
-  buffer.AddAtStart (1);
-  buffer.Begin ().WriteU8 (0x21);
-  ENSURE_WRITTEN_BYTES (buffer, 6, 0x21, 0, 0, 0, 0xab, 0xcd);
-  buffer.RemoveAtEnd (8);
-  if (buffer.GetSize () != 0) 
-    {
-      SetErrorStatus (false);
-    }
-
-  buffer = Buffer (6);
-  buffer.AddAtStart (9);
-  buffer.AddAtEnd (3);
-  i = buffer.End ();
-  i.Prev (1);
-  i.WriteU8 (1, 1);
-
-  buffer = Buffer (6);
-  buffer.AddAtStart (3);
-  buffer.RemoveAtEnd (8);
-  buffer.AddAtEnd (4);
-  i = buffer.End ();
-  i.Prev (4);
-  i.WriteU8 (1, 4);
-
-  buffer = Buffer (1);
-  buffer.AddAtEnd (100);
-  i = buffer.End ();
-  i.Prev (100);
-  i.WriteU8 (1, 100);
-
-  // Bug #54
-  {
-    const uint32_t actualSize = 72602;
-    const uint32_t chunkSize = 67624;
-    UniformVariable bytesRng (0, 256);
-
-    Buffer inputBuffer;
-    Buffer outputBuffer;
-    
-    inputBuffer.AddAtEnd (actualSize);
-    {
-      Buffer::Iterator iter = inputBuffer.Begin ();
-      for (uint32_t i = 0; i < actualSize; i++)
-        iter.WriteU8 (static_cast<uint8_t> (bytesRng.GetValue ()));
-    }
-
-    outputBuffer.AddAtEnd (chunkSize);
-    Buffer::Iterator iter = outputBuffer.End ();
-    iter.Prev (chunkSize);
-    iter.Write (inputBuffer.PeekData (), chunkSize);
-
-    NS_TEST_EXPECT_MSG_EQ (memcmp (inputBuffer.PeekData (), outputBuffer.PeekData (), chunkSize), 0, "memcp works");
-  }
-
-  buffer = Buffer (5);
-  buffer.AddAtEnd (2);
-  i = buffer.End ();
-  i.Prev (2);
-  i.WriteU8 (0);
-  i.WriteU8 (0x66);
-  ENSURE_WRITTEN_BYTES (buffer, 7, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x66);
-  Buffer frag0 = buffer.CreateFragment (0, 2);
-  ENSURE_WRITTEN_BYTES (frag0, 2, 0x00, 0x00);
-  Buffer frag1 = buffer.CreateFragment (2, 5);
-  ENSURE_WRITTEN_BYTES (frag1, 5, 0x00, 0x00, 0x00, 0x00, 0x66);
-  frag0.AddAtEnd (frag1);
-  ENSURE_WRITTEN_BYTES (buffer, 7, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x66);
-  ENSURE_WRITTEN_BYTES (frag0, 7, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x66);
-
-  buffer = Buffer (5);
-  buffer.AddAtStart (2);
-  i = buffer.Begin ();
-  i.WriteU8 (0x1);
-  i.WriteU8 (0x2);
-  buffer.AddAtEnd (2);
-  i = buffer.End ();
-  i.Prev (2);
-  i.WriteU8 (0x3);
-  i.WriteU8 (0x4);
-  ENSURE_WRITTEN_BYTES (buffer, 9, 0x1, 0x2, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3, 0x4);
-  Buffer other;
-  other.AddAtStart (9);
-  i = other.Begin ();
-  i.Write (buffer.Begin (), buffer.End ());
-  ENSURE_WRITTEN_BYTES (other, 9, 0x1, 0x2, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3, 0x4);
-
-  return GetErrorStatus ();
-}
-//-----------------------------------------------------------------------------
-class BufferTestSuite : public TestSuite
-{
-public:
-  BufferTestSuite ();
-};
-
-BufferTestSuite::BufferTestSuite ()
-  : TestSuite ("buffer", UNIT)
-{
-  AddTestCase (new BufferTest);
-}
-
-BufferTestSuite g_bufferTestSuite;
 
 } // namespace ns3
 
