@@ -48,6 +48,7 @@
 #include <errno.h>
 #include <limits>
 #include <stdlib.h>
+#include <time.h>
 
 NS_LOG_COMPONENT_DEFINE ("EmuNetDevice");
 
@@ -63,6 +64,10 @@ EmuNetDevice::GetTypeId (void)
   static TypeId tid = TypeId ("ns3::EmuNetDevice")
     .SetParent<NetDevice> ()
     .AddConstructor<EmuNetDevice> ()
+    .AddAttribute ("Mtu", "The MAC-level Maximum Transmission Unit",
+                   UintegerValue (0), // arbitrary un-used value because no setter
+                   MakeUintegerAccessor (&EmuNetDevice::GetMtu),
+                   MakeUintegerChecker<uint16_t> ())                   
     .AddAttribute ("Address", 
                    "The ns-3 MAC address of this (virtual) device.",
                    Mac48AddressValue (Mac48Address ("ff:ff:ff:ff:ff:ff")),
@@ -102,6 +107,14 @@ EmuNetDevice::GetTypeId (void)
                    MakePointerAccessor (&EmuNetDevice::m_queue),
                    MakePointerChecker<Queue> ())
 
+    .AddAttribute ("RxQueueSize", "Maximum size of the read queue.  "
+                   "This value limits number of packets that have been read "
+                   "from the network into a memory buffer but have not yet "
+                   "been processed by the simulator.",
+                   UintegerValue (1000),
+                   MakeUintegerAccessor (&EmuNetDevice::m_maxPendingReads),
+                   MakeUintegerChecker<uint32_t> ())
+
     //
     // Trace sources at the "top" of the net device, where packets transition
     // to/from higher layers.  These points do not really correspond to the 
@@ -180,7 +193,8 @@ EmuNetDevice::EmuNetDevice ()
   m_ifIndex (std::numeric_limits<uint32_t>::max ()),  // absurdly large value
   m_sll_ifindex (-1),
   m_isBroadcast (true),
-  m_isMulticast (false)
+  m_isMulticast (false),
+  m_pendingReadCount (0)
 {
   NS_LOG_FUNCTION (this);
   m_packetBuffer = new uint8_t[65536];
@@ -197,6 +211,10 @@ void
 EmuNetDevice::DoDispose()
 {
   NS_LOG_FUNCTION_NOARGS ();
+  if (m_readThread != 0)
+    {
+      StopDevice ();
+    }
   m_node = 0;
   NetDevice::DoDispose ();
 }
@@ -272,6 +290,14 @@ EmuNetDevice::StartDevice (void)
   Ptr<RealtimeSimulatorImpl> impl = DynamicCast<RealtimeSimulatorImpl> (Simulator::GetImplementation ());
   m_rtImpl = GetPointer (impl);
 
+  //
+  // A similar story exists for the node ID.  We can't just naively do a
+  // GetNode ()->GetId () since GetNode is going to give us a Ptr<Node> which
+  // is reference counted.  We need to stash away the node ID for use in the
+  // read thread.
+  //
+  m_nodeId = GetNode ()->GetId ();
+
   NS_LOG_LOGIC ("Creating socket");
 
   //
@@ -450,16 +476,16 @@ EmuNetDevice::CreateSocket (void)
       //
       // Execute the socket creation process image.
       //
-      status = ::execl (FindCreator ("emu-sock-creator").c_str (), 
+      status = ::execlp ("emu-sock-creator", 
                         "emu-sock-creator",                             // argv[0] (filename)
                         oss.str ().c_str (),                            // argv[1] (-p<path?
                         (char *)NULL);
 
       //
-      // If the execl successfully completes, it never returns.  If it returns it failed or the OS is
+      // If the execlp successfully completes, it never returns.  If it returns it failed or the OS is
       // broken.  In either case, we bail.
       //
-      NS_FATAL_ERROR ("EmuNetDevice::CreateSocket(): Back from execl(), errno = " << ::strerror (errno));
+      NS_FATAL_ERROR ("EmuNetDevice::CreateSocket(): Back from execlp(), errno = " << ::strerror (errno));
     }
   else
     {
@@ -587,52 +613,6 @@ EmuNetDevice::CreateSocket (void)
     }
 }
 
-std::string
-EmuNetDevice::FindCreator (std::string creatorName)
-{
-  NS_LOG_FUNCTION (creatorName);
-
-  std::list<std::string> locations;
-
-  // The path to the bits if we're sitting there with them
-  locations.push_back ("./");
-  locations.push_back ("./");
-
-  // The path to the bits if we're sitting in the root of the repo
-  locations.push_back ("./build/optimized/src/devices/emu/");
-  locations.push_back ("./build/debug/src/devices/emu/");
-
-  // if at the level of src (or build)
-  locations.push_back ("../build/optimized/src/devices/emu/");
-  locations.push_back ("../build/debug/src/devices/emu/");
-
-  // src/devices (or build/debug)
-  locations.push_back ("../../build/optimized/src/devices/emu/");
-  locations.push_back ("../../build/debug/src/devices/emu/");
-
-  // src/devices/emu (or build/debug/examples)
-  locations.push_back ("../../../build/optimized/src/devices/emu/");
-  locations.push_back ("../../../build/debug/src/devices/emu/");
-
-  // src/devices/emu (or build/debug/examples/emulation)
-  locations.push_back ("../../../../build/optimized/src/devices/emu/");
-  locations.push_back ("../../../../build/debug/src/devices/emu/");
-
-  for (std::list<std::string>::const_iterator i = locations.begin (); i != locations.end (); ++i)
-    {
-      struct stat st;
-
-      if (::stat ((*i + creatorName).c_str (), &st) == 0)
-	{
-          NS_LOG_INFO ("Found Creator " << *i + creatorName);                  
-	  return *i + creatorName;
-	}
-    }
-
-  NS_FATAL_ERROR ("EmuNetDevice::FindCreator(): Couldn't find creator");
-  return ""; // quiet compiler
-}
-
 void
 EmuNetDevice::StopDevice (void)
 {
@@ -660,6 +640,12 @@ EmuNetDevice::ForwardUp (uint8_t *buf, uint32_t len)
   free (buf);
   buf = 0;
 
+  {
+    CriticalSection cs (m_pendingReadMutex);
+    //std::cerr << std::endl << "EmuNetDevice main thread: m_pendingReadCount is " << m_pendingReadCount << std::endl;
+    --m_pendingReadCount;
+  }
+
   //
   // Trace sinks will expect complete packets, not packets without some of the
   // headers.
@@ -788,6 +774,31 @@ EmuNetDevice::ReadThread (void)
 
   for (;;) 
     {
+      //
+      // Too many pending reads at the same time leads to excessive memory allocations.  This counter prevents it.
+      // 
+      bool skip = false;
+      
+      {
+        CriticalSection cs (m_pendingReadMutex);            
+        //std::cerr << std::endl << "EmuNetDevice read thread: m_pendingReadCount is " << m_pendingReadCount << std::endl;
+        if (m_pendingReadCount >= m_maxPendingReads)
+          {
+            skip = true;
+          }
+        else
+          {
+            ++m_pendingReadCount;
+          }
+      }
+
+      if (skip)  
+        {           
+          struct timespec time = { 0, 100000000L }; // 100 ms
+          nanosleep (&time, NULL);
+          continue;
+        }
+
       //
       // to avoid any issues with a shared reference counted packet, we allocate a buffer on the heap and pass that
       // buffer into the ns-3 context thread where it will create the packet, copy the buffer and then free it.
@@ -809,10 +820,10 @@ EmuNetDevice::ReadThread (void)
           return;
         }
 
-      NS_LOG_INFO ("EmuNetDevice::ReadThread(): Received packet");
+      NS_LOG_INFO ("EmuNetDevice::EmuNetDevice(): Received packet on node " << m_nodeId);
       NS_LOG_INFO ("EmuNetDevice::ReadThread(): Scheduling handler");
       NS_ASSERT_MSG (m_rtImpl, "EmuNetDevice::ReadThread(): Realtime simulator implementation pointer not set");
-      m_rtImpl->ScheduleRealtimeNowWithContext (GetNode ()->GetId (), MakeEvent (&EmuNetDevice::ForwardUp, this, buf, len));
+      m_rtImpl->ScheduleRealtimeNowWithContext (m_nodeId, MakeEvent (&EmuNetDevice::ForwardUp, this, buf, len));
       buf = 0;
     }
 }
@@ -1086,7 +1097,7 @@ EmuNetDevice::IsBridge (void) const
 void
 EmuNetDevice::SetPromiscReceiveCallback (PromiscReceiveCallback cb)
 {
-  NS_FATAL_ERROR ("EmuNetDevice::SetPromiscReceiveCallback(): Not implemented");
+  m_promiscRxCallback = cb;
 }
 
   bool 
