@@ -21,7 +21,7 @@
 #ifndef MESH_PEERING_PROTOCOL_H
 #define MESH_PEERING_PROTOCOL_H
 
-#include "ns3/wifi-information-element-vector.h"
+#include "ns3/mesh-information-element-vector.h"
 
 namespace ns3
 {
@@ -35,10 +35,10 @@ public:
    * \name Inherited from WifiInformationElement
    * \{
    */
-  virtual WifiElementId ElementId () const;
-  virtual uint8_t  GetInformationSize () const;
-  virtual void SerializeInformation (Buffer::Iterator i) const;
-  virtual uint8_t DeserializeInformation (Buffer::Iterator i, uint8_t length);
+  virtual WifiInformationElementId ElementId () const;
+  virtual uint8_t GetInformationFieldSize () const;
+  virtual void SerializeInformationField (Buffer::Iterator i) const;
+  virtual uint8_t DeserializeInformationField (Buffer::Iterator i, uint8_t length);
   virtual void Print (std::ostream& os) const;
   ///\}
 private:
