@@ -40,7 +40,7 @@ public:
   virtual ~AarfWifiManager ();
 private:
   // overriden from base class
-  virtual class WifiRemoteStation *DoCreateStation (void) const;
+  virtual WifiRemoteStation *DoCreateStation (void) const;
   virtual void DoReportRxOk (WifiRemoteStation *station, 
                              double rxSnr, WifiMode txMode);
   virtual void DoReportRtsFailed (WifiRemoteStation *station);
