@@ -24,7 +24,7 @@
 
 namespace ns3 {
 
-class AarfcdWifiRemoteStation;
+struct AarfcdWifiRemoteStation;
 
 /**
  * \brief an implementation of the AARF-CD algorithm
@@ -43,7 +43,7 @@ public:
 
 private:
   // overriden from base class
-  virtual class WifiRemoteStation *DoCreateStation (void) const;
+  virtual WifiRemoteStation *DoCreateStation (void) const;
   virtual void DoReportRxOk (WifiRemoteStation *station, 
                              double rxSnr, WifiMode txMode);
   virtual void DoReportRtsFailed (WifiRemoteStation *station);
