@@ -32,6 +32,7 @@
 #include "qos-utils.h"
 #include "dcf.h"
 #include "ctrl-headers.h"
+#include "block-ack-manager.h"
 
 #include <map>
 #include <list>
@@ -137,13 +138,14 @@ public:
   void NextFragment (void);
   Ptr<Packet> GetFragmentPacket (WifiMacHeader *hdr);
   
-  void SetAccessClass (enum AccessClass ac);
+  void SetAccessCategory (enum AcIndex ac);
   void Queue (Ptr<const Packet> packet, const WifiMacHeader &hdr);
   void SetMsduAggregator (Ptr<MsduAggregator> aggr);
   void PushFront (Ptr<const Packet> packet, const WifiMacHeader &hdr);
   void CompleteConfig (void);
   void SetBlockAckThreshold (uint8_t threshold);
   uint8_t GetBlockAckThreshold (void) const;
+  void SetBlockAckInactivityTimeout (uint16_t timeout);
   void SendDelbaFrame (Mac48Address addr, uint8_t tid, bool byOriginator);
 
 private:
@@ -184,7 +186,7 @@ private:
    */
   void VerifyBlockAck (void);
   
-  AccessClass m_ac;
+  AcIndex m_ac;
   class Dcf;
   class TransmissionListener;
   class BlockAckEventListener;
@@ -220,6 +222,7 @@ private:
   enum BlockAckType m_blockAckType;
   Time m_currentPacketTimestamp;
   uint16_t m_blockAckInactivityTimeout;
+  struct Bar m_currentBar;
 };
 
 }  //namespace ns3
