@@ -60,19 +60,6 @@ InterferenceHelper::Event::GetEndTime (void) const
 {
   return m_endTime;
 }
-bool 
-InterferenceHelper::Event::Overlaps (Time time) const
-{
-  if (m_startTime <= time &&
-      m_endTime >= time) 
-    {
-      return true;
-    } 
-  else 
-    {
-      return false;
-    }
-}
 double 
 InterferenceHelper::Event::GetRxPowerW (void) const
 {
@@ -123,8 +110,9 @@ InterferenceHelper::NiChange::operator < (const InterferenceHelper::NiChange& o)
  ****************************************************************/
 
 InterferenceHelper::InterferenceHelper ()
-  : m_maxPacketDuration (Seconds(0)),
-    m_errorRateModel (0)  
+  : m_errorRateModel (0),
+    m_firstPower (0.0),
+    m_rxing (false)
 {}
 InterferenceHelper::~InterferenceHelper ()
 {
@@ -145,17 +133,10 @@ InterferenceHelper::Add (uint32_t size, WifiMode payloadMode,
      preamble,
      duration,
      rxPowerW);
-
-  m_maxPacketDuration = std::max(duration, m_maxPacketDuration);
   AppendEvent (event);
   return event;
 }
 
-Time 
-InterferenceHelper::GetMaxPacketDuration (void) const
-{
-  return m_maxPacketDuration;
-}
 
 void 
 InterferenceHelper::SetNoiseFigure (double value)
@@ -185,109 +166,92 @@ Time
 InterferenceHelper::GetEnergyDuration (double energyW)
 {
   Time now = Simulator::Now ();
-
-  // first, we iterate over all events and, each event
-  // which contributes energy to the channel now is 
-  // appended to the noise interference array.
-  Events::const_iterator i = m_events.begin ();
   double noiseInterferenceW = 0.0;
-  NiChanges ni;
-  while (i != m_events.end ()) 
-    {
-      Ptr<Event> ev = *i;
-      NS_ASSERT (ev->GetStartTime () <= now);
-      if (ev->GetEndTime () > now)
-	{
-          ni.push_back (NiChange (ev->GetEndTime (), -ev->GetRxPowerW ()));
-          noiseInterferenceW += ev->GetRxPowerW ();
-	}
-      i++;
-    }
-  if (noiseInterferenceW < energyW)
-    {
-      return MicroSeconds (0);
-    }
-
-  /* quicksort vector of NI changes by time. 
-   */
-  std::sort (ni.begin (), ni.end (), std::less<NiChange> ());
-
-  // Now, we iterate the piecewise linear noise function
   Time end = now;
-  for (NiChanges::const_iterator i = ni.begin (); i != ni.end (); i++) 
+  noiseInterferenceW = m_firstPower;
+  for (NiChanges::const_iterator i = m_niChanges.begin (); i != m_niChanges.end (); i++)
     {
       noiseInterferenceW += i->GetDelta ();
       end = i->GetTime ();
-      if (noiseInterferenceW < energyW) 
-	{
-	  break;
-	}
+      if (end < now)
+        {
+          continue;
+        }
+      if (noiseInterferenceW < energyW)
+	      {
+	        break;
+	      }
     }
-  return end - now;
+  return end > now ? end - now : MicroSeconds (0);
 }
 
 WifiMode 
 InterferenceHelper::GetPlcpHeaderMode (WifiMode payloadMode, WifiPreamble preamble)
 {
-  switch (payloadMode.GetStandard ())
-    {
-    case WIFI_PHY_STANDARD_holland:
-    case WIFI_PHY_STANDARD_80211a:
-      // IEEE Std 802.11-2007, 17.3.2
-      // actually this is only the first part of the PlcpHeader,
-      // because the last 16 bits of the PlcpHeader are using the
-      // same mode of the payload
-      return WifiPhy::Get6mba ();      
-      
-    case WIFI_PHY_STANDARD_80211b:
-      if (preamble == WIFI_PREAMBLE_LONG)
-        {
-          // IEEE Std 802.11-2007, sections 15.2.3 and 18.2.2.1 
-          return WifiPhy::Get1mbb ();
-        }
-      else //  WIFI_PREAMBLE_SHORT
-        {
-          // IEEE Std 802.11-2007, section 18.2.2.2
-          return WifiPhy::Get2mbb ();
-        }
-      
-    case WIFI_PHY_STANDARD_80211_10Mhz:
-      return WifiPhy::Get3mb10Mhz ();
-      
-    case WIFI_PHY_STANDARD_80211_5Mhz:
-      return WifiPhy::Get1_5mb5Mhz ();
-    
-    default:
-      NS_FATAL_ERROR("unknown standard");
-      return WifiMode ();
-    }
+  switch (payloadMode.GetModulationClass ())
+     {
+     case WIFI_MOD_CLASS_OFDM:
+       {
+         switch (payloadMode.GetBandwidth ()) {
+         case 5000000:
+           return WifiPhy::GetOfdmRate1_5MbpsBW5MHz ();
+         case 10000000:
+           return WifiPhy::GetOfdmRate3MbpsBW10MHz ();
+         default:
+           // IEEE Std 802.11-2007, 17.3.2
+           // actually this is only the first part of the PlcpHeader,
+           // because the last 16 bits of the PlcpHeader are using the
+           // same mode of the payload
+           return WifiPhy::GetOfdmRate6Mbps ();
+         }
+       }
+
+     case WIFI_MOD_CLASS_DSSS:
+       if (preamble == WIFI_PREAMBLE_LONG)
+         {
+           // IEEE Std 802.11-2007, sections 15.2.3 and 18.2.2.1 
+           return WifiPhy::GetDsssRate1Mbps ();
+         }
+       else //  WIFI_PREAMBLE_SHORT
+         {
+           // IEEE Std 802.11-2007, section 18.2.2.2
+           return WifiPhy::GetDsssRate2Mbps ();
+         }
+
+     default:
+       NS_FATAL_ERROR("unsupported modulation class");
+       return WifiMode ();
+     }
 }
 
 uint32_t
 InterferenceHelper::GetPlcpHeaderDurationMicroSeconds (WifiMode payloadMode, WifiPreamble preamble)
 {
-    switch (payloadMode.GetStandard ())
+  switch (payloadMode.GetModulationClass ())
     {
-    case WIFI_PHY_STANDARD_holland:
-    case WIFI_PHY_STANDARD_80211a:
-      // IEEE Std 802.11-2007, section 17.3.3 and figure 17-4
-      // also section 17.3.2.3, table 17-4
-      // We return the duration of the SIGNAL field only, since the
-      // SERVICE field (which strictly speaking belongs to the PLCP
-      // header, see section 17.3.2 and figure 17-1) is sent using the
-      // payload mode.  
-      return 4; 
-      
-    case WIFI_PHY_STANDARD_80211_10Mhz:
-      // IEEE Std 802.11-2007, section 17.3.2.3, table 17-4
-      return 8;
-      
-    case WIFI_PHY_STANDARD_80211_5Mhz:
-      // IEEE Std 802.11-2007, section 17.3.2.3, table 17-4
-      return 16;
+    case WIFI_MOD_CLASS_OFDM:
+      {
+        switch (payloadMode.GetBandwidth ()) {
+        case 20000000:
+        default:
+          // IEEE Std 802.11-2007, section 17.3.3 and figure 17-4
+          // also section 17.3.2.3, table 17-4
+          // We return the duration of the SIGNAL field only, since the
+          // SERVICE field (which strictly speaking belongs to the PLCP
+          // header, see section 17.3.2 and figure 17-1) is sent using the
+          // payload mode.
+          return 4;
+        case 10000000:
+          // IEEE Std 802.11-2007, section 17.3.2.3, table 17-4
+          return 8;
+        case 5000000:
+          // IEEE Std 802.11-2007, section 17.3.2.3, table 17-4
+          return 16;
+        }
+      }
 
-    case WIFI_PHY_STANDARD_80211b:
-        if (preamble == WIFI_PREAMBLE_SHORT)
+    case WIFI_MOD_CLASS_DSSS:
+      if (preamble == WIFI_PREAMBLE_SHORT)
         {
           // IEEE Std 802.11-2007, section 18.2.2.2 and figure 18-2
           return 24;
@@ -296,37 +260,39 @@ InterferenceHelper::GetPlcpHeaderDurationMicroSeconds (WifiMode payloadMode, Wif
         {
           // IEEE Std 802.11-2007, sections 18.2.2.1 and figure 18-1
           return 48;
-        }      
-      
+        }
+
     default:
-      NS_FATAL_ERROR("unknown standard");
+      NS_FATAL_ERROR("unsupported modulation class");
       return 0;
     }
-  
 }
 
 uint32_t 
 InterferenceHelper::GetPlcpPreambleDurationMicroSeconds (WifiMode payloadMode, WifiPreamble preamble)
 {
-  switch (payloadMode.GetStandard ())
+  switch (payloadMode.GetModulationClass ())
     {
-    case WIFI_PHY_STANDARD_holland:
-    case WIFI_PHY_STANDARD_80211a:
-      // IEEE Std 802.11-2007, section 17.3.3,  figure 17-4
-      // also section 17.3.2.3, table 17-4
-      return 16; 
-      
-    case WIFI_PHY_STANDARD_80211_10Mhz:
-      // IEEE Std 802.11-2007, section 17.3.3, table 17-4 
-      // also section 17.3.2.3, table 17-4
-      return 32;
-      
-    case WIFI_PHY_STANDARD_80211_5Mhz:
-      // IEEE Std 802.11-2007, section 17.3.3
-      // also section 17.3.2.3, table 17-4
-      return 64;
+    case WIFI_MOD_CLASS_OFDM:
+      {
+        switch (payloadMode.GetBandwidth ()) {
+        case 20000000:
+        default:
+          // IEEE Std 802.11-2007, section 17.3.3,  figure 17-4
+          // also section 17.3.2.3, table 17-4
+          return 16;
+        case 10000000:
+          // IEEE Std 802.11-2007, section 17.3.3, table 17-4
+          // also section 17.3.2.3, table 17-4
+          return 32;
+        case 5000000:
+          // IEEE Std 802.11-2007, section 17.3.3
+          // also section 17.3.2.3, table 17-4
+          return 64;
+        }
+      }
 
-    case WIFI_PHY_STANDARD_80211b:
+    case WIFI_MOD_CLASS_DSSS:
       if (preamble == WIFI_PREAMBLE_SHORT)
         {
           // IEEE Std 802.11-2007, section 18.2.2.2 and figure 18-2
@@ -337,9 +303,9 @@ InterferenceHelper::GetPlcpPreambleDurationMicroSeconds (WifiMode payloadMode, W
           // IEEE Std 802.11-2007, sections 18.2.2.1 and figure 18-1
           return 144;
         }
-      
+
     default:
-      NS_FATAL_ERROR("unknown standard");
+      NS_FATAL_ERROR("unsupported modulation class");
       return 0;
     }
 }
@@ -348,48 +314,39 @@ uint32_t
 InterferenceHelper::GetPayloadDurationMicroSeconds (uint32_t size, WifiMode payloadMode)
 {
   NS_LOG_FUNCTION(size << payloadMode);
-  switch (payloadMode.GetStandard ())
+
+  switch (payloadMode.GetModulationClass ())
     {
-    case WIFI_PHY_STANDARD_80211a:
-    case WIFI_PHY_STANDARD_holland:
-    case WIFI_PHY_STANDARD_80211_10Mhz: 
-    case WIFI_PHY_STANDARD_80211_5Mhz: 
+    case WIFI_MOD_CLASS_OFDM:
       {
         // IEEE Std 802.11-2007, section 17.3.2.3, table 17-4
         // corresponds to T_{SYM} in the table
-        uint32_t symbolDurationUs; 
-        switch (payloadMode.GetStandard ())
-          {       
-          case WIFI_PHY_STANDARD_holland:   
-          case WIFI_PHY_STANDARD_80211a:
-            symbolDurationUs = 4;
-            break;
-          case WIFI_PHY_STANDARD_80211_10Mhz: 
-            symbolDurationUs = 8;
-            break;
-          case WIFI_PHY_STANDARD_80211_5Mhz: 
-            symbolDurationUs = 16;
-            break;
-          case WIFI_PHY_STANDARD_80211b:
-            NS_FATAL_ERROR("can't happen here");
-            symbolDurationUs = 0; // quiet compiler
-            break;
-          default:
-            NS_FATAL_ERROR("unknown standard");
-            symbolDurationUs = 0; // quiet compiler
-            break;
-          }
-      
+        uint32_t symbolDurationUs;
+
+        switch (payloadMode.GetBandwidth ()) {
+        case 20000000:
+        default:
+          symbolDurationUs = 4;
+          break;
+        case 10000000:
+          symbolDurationUs = 8;
+          break;
+        case 5000000:
+          symbolDurationUs = 16;
+          break;
+        }
+
         // IEEE Std 802.11-2007, section 17.3.2.2, table 17-3
         // corresponds to N_{DBPS} in the table
         double numDataBitsPerSymbol = payloadMode.GetDataRate ()  * symbolDurationUs / 1e6;
 
         // IEEE Std 802.11-2007, section 17.3.5.3, equation (17-11)
         uint32_t numSymbols = lrint (ceil ((16 + size * 8.0 + 6.0)/numDataBitsPerSymbol));
-      
+
         return numSymbols*symbolDurationUs;
       }
-    case WIFI_PHY_STANDARD_80211b:
+
+    case WIFI_MOD_CLASS_DSSS:
       // IEEE Std 802.11-2007, section 18.2.3.5
       NS_LOG_LOGIC(" size=" << size
                    << " mode=" << payloadMode 
@@ -397,7 +354,7 @@ InterferenceHelper::GetPayloadDurationMicroSeconds (uint32_t size, WifiMode payl
       return lrint(ceil ((size * 8.0) / (payloadMode.GetDataRate () / 1.0e6)));
 
     default:
-      NS_FATAL_ERROR("unknown standard");
+      NS_FATAL_ERROR("unsupported modulation class");
       return 0;
     }
 }
@@ -414,24 +371,23 @@ InterferenceHelper::CalculateTxDuration (uint32_t size, WifiMode payloadMode, Wi
 void 
 InterferenceHelper::AppendEvent (Ptr<InterferenceHelper::Event> event)
 {
-  /* attempt to remove the events which are 
-   * not useful anymore. 
-   * i.e.: all events which end _before_
-   *       now - m_maxPacketDuration
-   */
-  
-  if (Simulator::Now () > GetMaxPacketDuration ())
+  Time now = Simulator::Now ();
+  if (!m_rxing)
     {
-      Time end = Simulator::Now () - GetMaxPacketDuration ();
-      Events::iterator i = m_events.begin ();
-      while (i != m_events.end () &&
-             (*i)->GetEndTime () <= end) 
+      NiChanges::iterator nowIterator = GetPosition (now);
+      for (NiChanges::iterator i = m_niChanges.begin (); i != nowIterator; i++)
         {
-          i++;
+          m_firstPower += i->GetDelta ();
         }
-      EraseEvents (m_events.begin (), i);
-    } 
-  m_events.push_back (event);
+      m_niChanges.erase (m_niChanges.begin (), nowIterator);
+      m_niChanges.insert (m_niChanges.begin (), NiChange (event->GetStartTime (), event->GetRxPowerW ())); 
+    }
+  else
+    {
+      AddNiChangeEvent (NiChange (event->GetStartTime (), event->GetRxPowerW ()));
+    }
+  AddNiChangeEvent(NiChange (event->GetEndTime (), -event->GetRxPowerW ()));
+
 }
 
 
@@ -452,35 +408,18 @@ InterferenceHelper::CalculateSnr (double signal, double noiseInterference, WifiM
 double
 InterferenceHelper::CalculateNoiseInterferenceW (Ptr<InterferenceHelper::Event> event, NiChanges *ni) const
 {
-  Events::const_iterator i = m_events.begin ();
-  double noiseInterference = 0.0;
-  while (i != m_events.end ()) 
+  double noiseInterference = m_firstPower;
+  NS_ASSERT (m_rxing);
+  for (NiChanges::const_iterator i = m_niChanges.begin () + 1; i != m_niChanges.end (); i++)
     {
-      if (event == (*i)) 
+      if ((event->GetEndTime () == i->GetTime ()) && event->GetRxPowerW () == -i->GetDelta ())
         {
-          i++;
-          continue;
+          break;
         }
-      if ((*i)->Overlaps (event->GetStartTime ())) 
-        {
-          noiseInterference += (*i)->GetRxPowerW ();
-        }
-      else if (event->Overlaps ((*i)->GetStartTime ())) 
-        {
-          ni->push_back (NiChange ((*i)->GetStartTime (), (*i)->GetRxPowerW ()));
-        }
-      if (event->Overlaps ((*i)->GetEndTime ())) 
-        {
-          ni->push_back (NiChange ((*i)->GetEndTime (), -(*i)->GetRxPowerW ()));
-        }
-      i++;
+      ni->push_back (*i);
     }
-  ni->push_back (NiChange (event->GetStartTime (), noiseInterference));
+  ni->insert (ni->begin (), NiChange (event->GetStartTime (), noiseInterference));
   ni->push_back (NiChange (event->GetEndTime (), 0));
-
-  /* quicksort vector of NI changes by time. */
-  std::sort (ni->begin (), ni->end (), std::less<NiChange> ());
-
   return noiseInterference;
 }
 
@@ -607,21 +546,28 @@ InterferenceHelper::CalculateSnrPer (Ptr<InterferenceHelper::Event> event)
 void
 InterferenceHelper::EraseEvents (void) 
 {  
-  for (Events::iterator i = m_events.begin (); i != m_events.end (); ++i)
-    {
-      *i = 0;
-    }
-  m_events.clear ();
+  m_niChanges.clear ();
+  m_firstPower = 0.0;
 }
+InterferenceHelper::NiChanges::iterator
+InterferenceHelper::GetPosition (Time moment)
+{
+  return std::upper_bound (m_niChanges.begin (), m_niChanges.end (), NiChange (moment, 0));
 
+}
 void
-InterferenceHelper::EraseEvents (Events::iterator start, Events::iterator end) 
-{  
-  for (Events::iterator i = start; i != end; ++i)
-    {
-      *i = 0;
-    }
-  m_events.erase (start, end);
+InterferenceHelper::AddNiChangeEvent (NiChange change)
+{
+  m_niChanges.insert (GetPosition (change.GetTime ()), change);
+}
+void
+InterferenceHelper::NotifyRxStart ()
+{
+  m_rxing = true;
+}
+void
+InterferenceHelper::NotifyRxEnd ()
+{
+  m_rxing = false;
 }
-
 } // namespace ns3
