@@ -829,7 +829,7 @@ MacLow::ReceiveOk (Ptr<Packet> packet, double rxSnr, WifiMode txMode, WifiPreamb
              data MPDUs with the Ack Policy subfield set to Block Ack, it shall discard
              them and shall send a DELBA frame using the normal access 
              mechanisms. */
-          AccessClass ac = QosUtilsMapTidToAc (hdr.GetQosTid ());
+          AcIndex ac = QosUtilsMapTidToAc (hdr.GetQosTid ());
           m_edcaListeners[ac]->BlockAckInactivityTimeout (hdr.GetAddr2 (), hdr.GetQosTid ());
           return;
         }
@@ -1401,7 +1401,7 @@ MacLow::SendCtsAfterRts (Mac48Address source, Time duration, WifiMode rtsTxMode,
   WifiMacTrailer fcs;
   packet->AddTrailer (fcs);
 
-  struct SnrTag tag;
+  SnrTag tag;
   tag.Set (rtsSnr);
   packet->AddPacketTag (tag);
 
@@ -1480,7 +1480,7 @@ MacLow::SendAckAfterData (Mac48Address source, Time duration, WifiMode dataTxMod
   WifiMacTrailer fcs;
   packet->AddTrailer (fcs);
 
-  struct SnrTag tag;
+  SnrTag tag;
   tag.Set (dataSnr);
   packet->AddPacketTag (tag);
 
@@ -1538,7 +1538,7 @@ MacLow::CreateBlockAckAgreement (const MgtAddBaResponseHeader *respHdr, Mac48Add
       AgreementsI it = m_bAckAgreements.find (std::make_pair (originator, respHdr->GetTid ()));
       Time timeout = MicroSeconds (1024 * agreement.GetTimeout ());
  
-      AccessClass ac = QosUtilsMapTidToAc (agreement.GetTid ());
+      AcIndex ac = QosUtilsMapTidToAc (agreement.GetTid ());
       
       it->second.first.m_inactivityEvent = Simulator::Schedule (timeout,
                                                                 &MacLowBlockAckEventListener::BlockAckInactivityTimeout,
@@ -1565,16 +1565,16 @@ MacLow::RxCompleteBufferedPacketsWithSmallerSequence (uint16_t seq, Mac48Address
   AgreementsI it = m_bAckAgreements.find (std::make_pair (originator, tid));
   if (it != m_bAckAgreements.end ())
     {
-      BufferedPacketI i = (*it).second.second.begin ();
       uint16_t endSequence = ((*it).second.first.GetStartingSequence () + 2047) % 4096;
       uint16_t mappedStart = QosUtilsMapSeqControlToUniqueInteger (seq, endSequence);
-      uint16_t guard = (*it).second.first.GetStartingSequence ();
+      uint16_t guard = (*it).second.second.begin ()->second.GetSequenceControl() & 0xfff0;
       BufferedPacketI last = (*it).second.second.begin ();
 
+      BufferedPacketI i = (*it).second.second.begin ();
       for (; i != (*it).second.second.end () &&
              QosUtilsMapSeqControlToUniqueInteger ((*i).second.GetSequenceNumber (), endSequence) < mappedStart;)
         {
-          while (i != (*it).second.second.end () && guard == (*i).second.GetSequenceControl ())
+          if (guard == (*i).second.GetSequenceControl ())
             {
               if (!(*i).second.IsMoreFragments ())
                 {
@@ -1585,18 +1585,34 @@ MacLow::RxCompleteBufferedPacketsWithSmallerSequence (uint16_t seq, Mac48Address
                     }
                   m_rxCallback ((*last).first, &(*last).second);
                   last++;
+                  /* go to next packet */
+                  while (i != (*it).second.second.end () && ((guard >> 4) & 0x0fff) == (*i).second.GetSequenceNumber ())
+                    {
+                      i++;
+                    }
+                  if (i != (*it).second.second.end ())
+                    {
+                      guard = (*i).second.GetSequenceControl () & 0xfff0;
+                      last = i;
+                    }
+                }
+              else
+                {
+                  guard++;
                 }
-              guard = (*i).second.IsMoreFragments () ? (guard + 1) : ((guard + 16) & 0xfff0);
             }
-          /* go to next packet */
-          while (i != (*it).second.second.end () && ((guard >> 4) & 0x0fff) == (*i).second.GetSequenceNumber ())
+          else
             {
-              i++;
-            }
-          if (i != (*it).second.second.end ())
-            {
-              guard = (*i).second.GetSequenceControl () & 0xfff0;
-              last = i;
+              /* go to next packet */
+              while (i != (*it).second.second.end () && ((guard >> 4) & 0x0fff) == (*i).second.GetSequenceNumber ())
+                {
+                  i++;
+                }
+              if (i != (*it).second.second.end ())
+                {
+                  guard = (*i).second.GetSequenceControl () & 0xfff0;
+                  last = i;
+                }
             }
         }
       (*it).second.second.erase ((*it).second.second.begin (), i);
@@ -1715,7 +1731,7 @@ MacLow::SendBlockAckAfterBlockAckRequest (const CtrlBAckRequestHeader reqHdr, Ma
           /* All packets with smaller sequence than starting sequence control must be passed up to Wifimac 
            * See 9.10.3 in IEEE8022.11e standard.
            */
-          RxCompleteBufferedPacketsWithSmallerSequence ((startingSeqCtrl>>4)&0xfff0, originator, tid);
+          RxCompleteBufferedPacketsWithSmallerSequence ((startingSeqCtrl>>4)&0x0fff, originator, tid);
 
           std::list<BufferedPacket>::iterator i = (*it).second.second.begin ();
 
@@ -1830,8 +1846,8 @@ MacLow::ResetBlockAckInactivityTimerIfNeeded (BlockAckAgreement &agreement)
       agreement.m_inactivityEvent.Cancel ();
       Time timeout = MicroSeconds (1024 * agreement.GetTimeout ());
 
-      AccessClass ac = QosUtilsMapTidToAc (agreement.GetTid ());
-      //std::map<AccessClass, MacLowTransmissionListener*>::iterator it = m_edcaListeners.find (ac);
+      AcIndex ac = QosUtilsMapTidToAc (agreement.GetTid ());
+      //std::map<AcIndex, MacLowTransmissionListener*>::iterator it = m_edcaListeners.find (ac);
       //NS_ASSERT (it != m_edcaListeners.end ());
 
       agreement.m_inactivityEvent = Simulator::Schedule (timeout, 
@@ -1843,7 +1859,7 @@ MacLow::ResetBlockAckInactivityTimerIfNeeded (BlockAckAgreement &agreement)
 }
 
 void
-MacLow::RegisterBlockAckListenerForAc (enum AccessClass ac, MacLowBlockAckEventListener *listener)
+MacLow::RegisterBlockAckListenerForAc (enum AcIndex ac, MacLowBlockAckEventListener *listener)
 {
   m_edcaListeners.insert (std::make_pair (ac, listener));
 }
