@@ -85,6 +85,9 @@ QadhocWifiMac::QadhocWifiMac ()
   m_dcfManager = new DcfManager ();
   m_dcfManager->SetupLowListener (m_low);
 
+  // Construct the EDCAFs. The ordering is important - highest
+  // priority (see Table 9-1 in IEEE 802.11-2007) must be created
+  // first.
   SetQueue (AC_VO);
   SetQueue (AC_VI);
   SetQueue (AC_BE);
@@ -278,7 +281,7 @@ QadhocWifiMac::Enqueue (Ptr<const Packet> packet, Mac48Address to)
   if (tid < 8)
     {
       hdr.SetQosTid (tid);
-      AccessClass ac = QosUtilsMapTidToAc (tid);
+      AcIndex ac = QosUtilsMapTidToAc (tid);
       m_queues[ac]->Queue (packet, hdr);
     }
   else
@@ -404,7 +407,7 @@ QadhocWifiMac::Receive (Ptr<Packet> packet, const WifiMacHeader *hdr)
               else
                 {
                   /* We must notify correct queue tear down of agreement */
-                  AccessClass ac = QosUtilsMapTidToAc (delBaHdr.GetTid ());
+                  AcIndex ac = QosUtilsMapTidToAc (delBaHdr.GetTid ());
                   m_queues[ac]->GotDelBaFrame (&delBaHdr, hdr->GetAddr2 ());
                 }
             }
@@ -458,14 +461,14 @@ QadhocWifiMac::GetBKQueue (void) const
 }
 
 void
-QadhocWifiMac::SetQueue (enum AccessClass ac)
+QadhocWifiMac::SetQueue (enum AcIndex ac)
 {
   Ptr<EdcaTxopN> edca = CreateObject<EdcaTxopN> ();
   edca->SetLow (m_low);
   edca->SetManager (m_dcfManager);
   edca->SetTypeOfStation (ADHOC_STA);
   edca->SetTxMiddle (m_txMiddle);
-  edca->SetAccessClass (ac);
+  edca->SetAccessCategory (ac);
   edca->CompleteConfig ();
   m_queues.insert (std::make_pair(ac, edca));
 }
