@@ -23,6 +23,7 @@
 #include "ns3/simulator.h"
 #include "ns3/string.h"
 #include "ns3/pointer.h"
+#include "ns3/boolean.h"
 
 #include "qos-tag.h"
 #include "edca-txop-n.h"
@@ -108,6 +109,9 @@ QstaWifiMac::QstaWifiMac ()
   m_dcfManager = new DcfManager ();
   m_dcfManager->SetupLowListener (m_low);
 
+  // Construct the EDCAFs. The ordering is important - highest
+  // priority (see Table 9-1 in IEEE 802.11-2007) must be created
+  // first.
   SetQueue (AC_VO);
   SetQueue (AC_VI);
   SetQueue (AC_BE);
@@ -169,6 +173,18 @@ QstaWifiMac::SetAckTimeout (Time ackTimeout)
   m_low->SetAckTimeout (ackTimeout);
 }
 
+void 
+QstaWifiMac::SetBasicBlockAckTimeout (Time blockAckTimeout)
+{
+  m_low->SetBasicBlockAckTimeout (blockAckTimeout);
+}
+
+void 
+QstaWifiMac::SetCompressedBlockAckTimeout (Time blockAckTimeout)
+{
+  m_low->SetCompressedBlockAckTimeout (blockAckTimeout);
+}
+
 void
 QstaWifiMac::SetCtsTimeout (Time ctsTimeout)
 {
@@ -205,6 +221,18 @@ QstaWifiMac::GetAckTimeout (void) const
  return m_low->GetAckTimeout ();
 }
 
+Time 
+QstaWifiMac::GetBasicBlockAckTimeout (void) const
+{
+  return m_low->GetBasicBlockAckTimeout ();
+}
+
+Time 
+QstaWifiMac::GetCompressedBlockAckTimeout (void) const
+{
+  return m_low->GetCompressedBlockAckTimeout ();
+}
+
 Time
 QstaWifiMac::GetCtsTimeout (void) const
 {
@@ -521,7 +549,7 @@ QstaWifiMac::Enqueue (Ptr<const Packet> packet, Mac48Address to)
   if (tid < 8)
     {
       hdr.SetQosTid (tid);
-      AccessClass ac = QosUtilsMapTidToAc (tid);
+      AcIndex ac = QosUtilsMapTidToAc (tid);
       m_queues[ac]->Queue (packet, hdr);
     }
   else
@@ -544,7 +572,7 @@ QstaWifiMac::Receive (Ptr<Packet> packet, const WifiMacHeader *hdr)
   NS_LOG_FUNCTION (this);
   NS_ASSERT (!hdr->IsCtl ());
   if (hdr->GetAddr1 () != GetAddress () &&
-      !hdr->GetAddr1 ().IsBroadcast ())
+      !hdr->GetAddr1 ().IsGroup ())
     {
       NS_LOG_LOGIC ("packet is not for us");
     }
@@ -649,13 +677,12 @@ QstaWifiMac::Receive (Ptr<Packet> packet, const WifiMacHeader *hdr)
               m_state = ASSOCIATED;
               NS_LOG_DEBUG ("assoc completed"); 
               SupportedRates rates = assocResp.GetSupportedRates ();
-              WifiRemoteStation *ap = m_stationManager->Lookup (hdr->GetAddr2 ());
               for (uint32_t i = 0; i < m_phy->GetNModes (); i++)
                 {
                   WifiMode mode = m_phy->GetMode (i);
                   if (rates.IsSupportedRate (mode.GetDataRate ()))
                     {
-                      ap->AddSupportedMode (mode);
+                      m_stationManager->AddSupportedMode (hdr->GetAddr2 (), mode);
                       if (rates.IsBasicRate (mode.GetDataRate ()))
                         {
                           m_stationManager->AddBasicMode (mode);
@@ -674,6 +701,43 @@ QstaWifiMac::Receive (Ptr<Packet> packet, const WifiMacHeader *hdr)
             }
         }
     }
+  else if (hdr->IsAction ())
+    {
+      WifiActionHeader actionHdr;
+      packet->RemoveHeader (actionHdr);
+      if (actionHdr.GetCategory () == WifiActionHeader::BLOCK_ACK &&
+          actionHdr.GetAction().blockAck == WifiActionHeader::BLOCK_ACK_ADDBA_REQUEST)
+        {
+          MgtAddBaRequestHeader reqHdr;
+          packet->RemoveHeader (reqHdr);
+          SendAddBaResponse (&reqHdr, hdr->GetAddr2 ());
+        }
+      else if (actionHdr.GetCategory () == WifiActionHeader::BLOCK_ACK &&
+               actionHdr.GetAction().blockAck == WifiActionHeader::BLOCK_ACK_ADDBA_RESPONSE)
+        {
+          MgtAddBaResponseHeader respHdr;
+          packet->RemoveHeader (respHdr);
+          m_queues[QosUtilsMapTidToAc (respHdr.GetTid ())]->GotAddBaResponse (&respHdr, hdr->GetAddr2 ());
+        }
+      else if (actionHdr.GetCategory () == WifiActionHeader::BLOCK_ACK &&
+               actionHdr.GetAction().blockAck == WifiActionHeader::BLOCK_ACK_DELBA)
+        {
+          MgtDelBaHeader delBaHdr;
+          packet->RemoveHeader (delBaHdr);
+          if (delBaHdr.IsByOriginator ())
+            {
+              /* Delba frame was sent by originator, this means that an ingoing established
+                 agreement exists in MacLow */
+              m_low->DestroyBlockAckAgreement (hdr->GetAddr2 (), delBaHdr.GetTid ());
+            }
+          else
+            {
+              /* We must notify correct queue tear down of agreement */
+              AcIndex ac = QosUtilsMapTidToAc (delBaHdr.GetTid ());
+              m_queues[ac]->GotDelBaFrame (&delBaHdr, hdr->GetAddr2 ());
+            }
+        }
+    }
 }
 
 SupportedRates
@@ -724,15 +788,26 @@ QstaWifiMac::GetBKQueue (void) const
 }
 
 void
-QstaWifiMac::SetQueue (enum AccessClass ac)
+QstaWifiMac::SetQueue (enum AcIndex ac)
 {
   Ptr<EdcaTxopN> edca = CreateObject<EdcaTxopN> ();
   edca->SetLow (m_low);
   edca->SetManager (m_dcfManager);
   edca->SetTypeOfStation (STA);
   edca->SetTxMiddle (m_txMiddle);
+  edca->SetAccessCategory (ac);
+  edca->CompleteConfig ();
   m_queues.insert (std::make_pair(ac, edca));
 }
+void
+QstaWifiMac::DoStart ()
+{
+  for (Queues::iterator i = m_queues.begin (); i != m_queues.end (); ++i)
+    {
+      i->second->Start ();
+    }
+  WifiMac::DoStart ();
+}
 
 void 
 QstaWifiMac::FinishConfigureStandard (enum WifiPhyStandard standard)
@@ -775,5 +850,59 @@ QstaWifiMac::FinishConfigureStandard (enum WifiPhyStandard standard)
     }
 }
 
+void
+QstaWifiMac::SendAddBaResponse (const MgtAddBaRequestHeader *reqHdr, Mac48Address originator)
+{
+  NS_LOG_FUNCTION (this);
+  WifiMacHeader hdr;
+  hdr.SetAction ();
+  hdr.SetAddr1 (originator);
+  hdr.SetAddr2 (m_low->GetAddress ());
+  hdr.SetAddr3 (m_low->GetAddress ());
+  hdr.SetDsNotFrom ();
+  hdr.SetDsNotTo ();
+
+  MgtAddBaResponseHeader respHdr;
+  StatusCode code;
+  code.SetSuccess ();
+  respHdr.SetStatusCode (code);
+  //Here a control about queues type?
+  respHdr.SetAmsduSupport (reqHdr->IsAmsduSupported ());
+
+  if (reqHdr->IsImmediateBlockAck ())
+    {
+      respHdr.SetImmediateBlockAck ();
+    }
+  else
+    {
+      respHdr.SetDelayedBlockAck ();
+    }
+  respHdr.SetTid (reqHdr->GetTid ());
+  /* For now there's not no control about limit of reception.
+     We assume that receiver has no limit on reception.
+     However we assume that a receiver sets a bufferSize in order to satisfy
+     next equation:
+     (bufferSize + 1) % 16 = 0
+     So if a recipient is able to buffer a packet, it should be also able to buffer
+     all possible packet's fragments.
+     See section 7.3.1.14 in IEEE802.11e for more details. */
+  respHdr.SetBufferSize (1023);
+  respHdr.SetTimeout (reqHdr->GetTimeout ());
+
+  WifiActionHeader actionHdr;
+  WifiActionHeader::ActionValue action;
+  action.blockAck = WifiActionHeader::BLOCK_ACK_ADDBA_RESPONSE;
+  actionHdr.SetAction (WifiActionHeader::BLOCK_ACK, action);
+
+  Ptr<Packet> packet = Create<Packet> ();
+  packet->AddHeader (respHdr);
+  packet->AddHeader (actionHdr);
+  
+  /* ns3::MacLow have to buffer all correctly received packet for this block ack session */
+  m_low->CreateBlockAckAgreement (&respHdr, originator, reqHdr->GetStartingSequence ());
+
+  //Better a management queue? 
+  m_queues[QosUtilsMapTidToAc (reqHdr->GetTid ())]->PushFront (packet, hdr);
+}
 
 }  //namespace ns3
