@@ -87,9 +87,9 @@ public:
   /**
    * Set the class, type and attributes for the Msdu aggregator
    *
-   * \param accessClass access class for which we are setting aggregator. Possibilities
+   * \param ac access category for which we are setting aggregator. Possibilities
    *  are: AC_BK, AC_BE, AC_VI, AC_VO.
-   * \param type the type of ns3::WifiMac to create.
+   * \param type the type of ns3::MsduAggregator to create.
    * \param n0 the name of the attribute to set
    * \param v0 the value of the attribute to set
    * \param n1 the name of the attribute to set
@@ -102,11 +102,33 @@ public:
    * All the attributes specified in this method should exist
    * in the requested aggregator.
    */
-  void SetMsduAggregatorForAc (AccessClass accessClass, std::string type,
+  void SetMsduAggregatorForAc (AcIndex ac, std::string type,
                                std::string n0 = "", const AttributeValue &v0 = EmptyAttributeValue (),
                                std::string n1 = "", const AttributeValue &v1 = EmptyAttributeValue (),
                                std::string n2 = "", const AttributeValue &v2 = EmptyAttributeValue (),
                                std::string n3 = "", const AttributeValue &v3 = EmptyAttributeValue ());
+  /**
+   * This method sets value of block ack threshold for a specific access class.
+   * If number of packets in the respective queue reaches this value block ack mechanism
+   * is used.
+   *
+   * \param ac access category for which we are setting block ack threshold. Possibilities
+   * are: AC_BK, AC_BE, AC_VI, AC_VO.
+   * \param threshold the threshold (number of packets)
+   */
+  void SetBlockAckThresholdForAc (enum AcIndex ac, uint8_t threshold);
+  /**
+   * Sets value of block ack inactivity timeout for a specific access class. <i>timeout</i>
+   * represents number of blocks of 1024 microseconds. When this timer expires the relative
+   * block ack agreement is teared down. Timer is reset in an recipient station every time
+   * that a block ack request or a MPDU with ack policy BLOCK ACK is received.
+   * Timer is reset in a originator station every time that a block ack frame is received.
+   * 
+   * \param ac access category for which we are setting block ack threshold. Possibilities
+   * are: AC_BK, AC_BE, AC_VI, AC_VO.
+   * \param timeout number of block of 1024 microseconds.
+   */
+  void SetBlockAckInactivityTimeoutForAc (enum AcIndex ac, uint16_t timeout);
 private:
   /**
    * \internal
@@ -115,11 +137,17 @@ private:
    * This method implements the pure virtual method defined in \ref ns3::WifiMacHelper.
    */
   virtual Ptr<WifiMac> Create (void) const;
-  void Setup (Ptr<WifiMac> mac, enum AccessClass ac, std::string dcaAttrName) const;
+  void Setup (Ptr<WifiMac> mac, enum AcIndex ac, std::string dcaAttrName) const;
 
 
   ObjectFactory m_mac;
-  std::map<AccessClass, ObjectFactory> m_aggregators;
+  std::map<AcIndex, ObjectFactory> m_aggregators;
+  /* 
+   * Next maps contain, for every access category, the values for
+   * block ack threshold and block ack inactivity timeout.
+   */
+  std::map<AcIndex, uint8_t> m_bAckThresholds;
+  std::map<AcIndex, uint16_t> m_bAckInactivityTimeouts;
 };
 
 } //namespace ns3
