@@ -84,7 +84,7 @@ Ipv4L3Protocol::GetTypeId (void)
 Ipv4L3Protocol::Ipv4L3Protocol()
   : m_identification (0)
 {
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this);
 }
 
 Ipv4L3Protocol::~Ipv4L3Protocol ()
@@ -205,7 +205,7 @@ Ipv4L3Protocol::DoDispose (void)
 void
 Ipv4L3Protocol::SetupLoopback (void)
 {
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this);
 
   Ptr<Ipv4Interface> interface = CreateObject<Ipv4Interface> ();
   Ptr<LoopbackNetDevice> device = 0;
@@ -240,7 +240,6 @@ Ipv4L3Protocol::SetupLoopback (void)
 void 
 Ipv4L3Protocol::SetDefaultTtl (uint8_t ttl)
 {
-  NS_LOG_FUNCTION_NOARGS ();
   m_defaultTtl = ttl;
 }
     
@@ -274,7 +273,6 @@ Ipv4L3Protocol::AddIpv4Interface (Ptr<Ipv4Interface>interface)
 Ptr<Ipv4Interface>
 Ipv4L3Protocol::GetInterface (uint32_t index) const
 {
-  NS_LOG_FUNCTION (this << index);
   if (index < m_interfaces.size ())
     {
       return m_interfaces[index];
@@ -285,7 +283,6 @@ Ipv4L3Protocol::GetInterface (uint32_t index) const
 uint32_t 
 Ipv4L3Protocol::GetNInterfaces (void) const
 {
-  NS_LOG_FUNCTION_NOARGS ();
   return m_interfaces.size ();
 }
 
@@ -293,8 +290,6 @@ int32_t
 Ipv4L3Protocol::GetInterfaceForAddress (
   Ipv4Address address) const
 {
-  NS_LOG_FUNCTION (this << address);
-
   int32_t interface = 0;
   for (Ipv4InterfaceList::const_iterator i = m_interfaces.begin (); 
        i != m_interfaces.end (); 
@@ -317,8 +312,6 @@ Ipv4L3Protocol::GetInterfaceForPrefix (
   Ipv4Address address, 
   Ipv4Mask mask) const
 {
-  NS_LOG_FUNCTION (this << address << mask);
-
   int32_t interface = 0;
   for (Ipv4InterfaceList::const_iterator i = m_interfaces.begin (); 
        i != m_interfaces.end (); 
@@ -340,8 +333,6 @@ int32_t
 Ipv4L3Protocol::GetInterfaceForDevice (
   Ptr<const NetDevice> device) const
 {
-  NS_LOG_FUNCTION (this << device->GetIfIndex());
-
   int32_t interface = 0;
   for (Ipv4InterfaceList::const_iterator i = m_interfaces.begin (); 
        i != m_interfaces.end (); 
@@ -359,8 +350,6 @@ Ipv4L3Protocol::GetInterfaceForDevice (
 bool
 Ipv4L3Protocol::IsDestinationAddress (Ipv4Address address, uint32_t iif) const
 {
-  NS_LOG_FUNCTION (this << address << " " << iif);
-
   // First check the incoming interface for a unicast address match
   for (uint32_t i = 0; i < GetNAddresses (iif); i++)
     {
@@ -480,16 +469,21 @@ Ipv4L3Protocol::Receive( Ptr<NetDevice> device, Ptr<const Packet> p, uint16_t pr
     {
       NS_LOG_LOGIC ("Forwarding to raw socket"); 
       Ptr<Ipv4RawSocketImpl> socket = *i;
-      socket->ForwardUp (packet, ipHeader, device);
+      socket->ForwardUp (packet, ipHeader, ipv4Interface);
     }
 
   NS_ASSERT_MSG (m_routingProtocol != 0, "Need a routing protocol object to process packets");
-  m_routingProtocol->RouteInput (packet, ipHeader, device, 
+  if (! m_routingProtocol->RouteInput (packet, ipHeader, device, 
     MakeCallback (&Ipv4L3Protocol::IpForward, this),
     MakeCallback (&Ipv4L3Protocol::IpMulticastForward, this),
     MakeCallback (&Ipv4L3Protocol::LocalDeliver, this),
     MakeCallback (&Ipv4L3Protocol::RouteInputError, this)
-  );
+  ))
+    {
+      NS_LOG_WARN ("No route found for forwarding packet.  Drop.");
+      m_dropTrace (ipHeader, packet, DROP_NO_ROUTE, m_node->GetObject<Ipv4> (), interface);
+    }
+
 
 }
 
@@ -513,6 +507,15 @@ Ipv4L3Protocol::IsUnicast (Ipv4Address ad, Ipv4Mask interfaceMask) const
   return !ad.IsMulticast () && !ad.IsSubnetDirectedBroadcast (interfaceMask);
 }
 
+void 
+Ipv4L3Protocol::Send (Ptr<Packet> packet, 
+                      Ipv4Header ipHeader,
+                      Ptr<Ipv4Route> route)
+{
+  NS_LOG_FUNCTION (this << packet << ipHeader << route);
+  SendRealOut (route, packet, ipHeader);
+}
+
 void 
 Ipv4L3Protocol::Send (Ptr<Packet> packet, 
             Ipv4Address source, 
@@ -604,10 +607,10 @@ Ipv4L3Protocol::Send (Ptr<Packet> packet,
       // returned to the transport protocol with a source address but
       // there was no next hop available yet (since a route may need
       // to be queried).  
-      NS_FATAL_ERROR ("This case not yet implemented");
+      NS_FATAL_ERROR ("Ipv4L3Protocol::Send case 4: This case not yet implemented");
     }
   // 5) packet is not broadcast, and route is NULL (e.g., a raw socket call)
-  NS_LOG_LOGIC ("Ipv4L3Protocol::Send case 4:  passed in with no route " << destination);
+  NS_LOG_LOGIC ("Ipv4L3Protocol::Send case 5:  passed in with no route " << destination);
   Socket::SocketErrno errno_; 
   Ptr<NetDevice> oif (0); // unused for now
   ipHeader = BuildHeader (source, destination, protocol, packet->GetSize (), ttl, mayFragment);
@@ -645,7 +648,7 @@ Ipv4L3Protocol::BuildHeader (
             uint8_t ttl,
             bool mayFragment)
 {
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this << source << destination << (uint16_t)protocol << payloadSize << (uint16_t)ttl << mayFragment);
   Ipv4Header ipHeader;
   ipHeader.SetSource (source);
   ipHeader.SetDestination (destination);
@@ -731,7 +734,7 @@ Ipv4L3Protocol::SendRealOut (Ptr<Ipv4Route> route,
 void
 Ipv4L3Protocol::IpMulticastForward (Ptr<Ipv4MulticastRoute> mrtentry, Ptr<const Packet> p, const Ipv4Header &header)
 {
-  NS_LOG_FUNCTION (mrtentry << p << header);
+  NS_LOG_FUNCTION (this << mrtentry << p << header);
   NS_LOG_LOGIC ("Multicast forwarding logic for node: " << m_node->GetId ());
   // The output interfaces we could forward this onto are encoded
   // in the OutputTtl of the Ipv4MulticastRoute
@@ -755,7 +758,7 @@ Ipv4L3Protocol::IpMulticastForward (Ptr<Ipv4MulticastRoute> mrtentry, Ptr<const
           rtentry->SetGateway (Ipv4Address::GetAny ());
           rtentry->SetOutputDevice (GetNetDevice (i));
           SendRealOut (rtentry, packet, h);
-          return; 
+          continue; 
         }
     }
 }
@@ -764,7 +767,7 @@ Ipv4L3Protocol::IpMulticastForward (Ptr<Ipv4MulticastRoute> mrtentry, Ptr<const
 void
 Ipv4L3Protocol::IpForward (Ptr<Ipv4Route> rtentry, Ptr<const Packet> p, const Ipv4Header &header)
 {
-  NS_LOG_FUNCTION (rtentry << p << header);
+  NS_LOG_FUNCTION (this << rtentry << p << header);
   NS_LOG_LOGIC ("Forwarding logic for node: " << m_node->GetId ());
   // Forwarding
   Ipv4Header ipHeader = header;
@@ -804,7 +807,7 @@ Ipv4L3Protocol::LocalDeliver (Ptr<const Packet> packet, Ipv4Header const&ip, uin
       // RX_ENDPOINT_UNREACH codepath
       Ptr<Packet> copy = p->Copy ();
       enum Ipv4L4Protocol::RxStatus status = 
-        protocol->Receive (p, ip.GetSource (), ip.GetDestination (), GetInterface (iif));
+        protocol->Receive (p, ip, GetInterface (iif));
       switch (status) {
       case Ipv4L4Protocol::RX_OK:
         // fall through
@@ -853,7 +856,6 @@ Ipv4L3Protocol::AddAddress (uint32_t i, Ipv4InterfaceAddress address)
 Ipv4InterfaceAddress 
 Ipv4L3Protocol::GetAddress (uint32_t interfaceIndex, uint32_t addressIndex) const
 {
-  NS_LOG_FUNCTION (this << interfaceIndex << addressIndex);
   Ptr<Ipv4Interface> interface = GetInterface (interfaceIndex);
   return interface->GetAddress (addressIndex);
 }
@@ -861,7 +863,6 @@ Ipv4L3Protocol::GetAddress (uint32_t interfaceIndex, uint32_t addressIndex) cons
 uint32_t 
 Ipv4L3Protocol::GetNAddresses (uint32_t interface) const
 {
-  NS_LOG_FUNCTION (this << interface);
   Ptr<Ipv4Interface> iface = GetInterface (interface);
   return iface->GetNAddresses ();
 }
@@ -887,7 +888,7 @@ Ipv4Address
 Ipv4L3Protocol::SelectSourceAddress (Ptr<const NetDevice> device,
     Ipv4Address dst, Ipv4InterfaceAddress::InterfaceAddressScope_e scope)
 {
-  NS_LOG_FUNCTION (device << dst << scope);
+  NS_LOG_FUNCTION (this << device << dst << scope);
   Ipv4Address addr ("0.0.0.0");
   Ipv4InterfaceAddress iaddr; 
   bool found = false;
@@ -939,7 +940,7 @@ Ipv4L3Protocol::SelectSourceAddress (Ptr<const NetDevice> device,
 void 
 Ipv4L3Protocol::SetMetric (uint32_t i, uint16_t metric)
 {
-  NS_LOG_FUNCTION (i << metric);
+  NS_LOG_FUNCTION (this << i << metric);
   Ptr<Ipv4Interface> interface = GetInterface (i);
   interface->SetMetric (metric);
 }
@@ -947,7 +948,6 @@ Ipv4L3Protocol::SetMetric (uint32_t i, uint16_t metric)
 uint16_t
 Ipv4L3Protocol::GetMetric (uint32_t i) const
 {
-  NS_LOG_FUNCTION (i);
   Ptr<Ipv4Interface> interface = GetInterface (i);
   return interface->GetMetric ();
 }
@@ -955,7 +955,6 @@ Ipv4L3Protocol::GetMetric (uint32_t i) const
 uint16_t 
 Ipv4L3Protocol::GetMtu (uint32_t i) const
 {
-  NS_LOG_FUNCTION (this << i);
   Ptr<Ipv4Interface> interface = GetInterface (i);
   return interface->GetDevice ()->GetMtu ();
 }
@@ -963,7 +962,6 @@ Ipv4L3Protocol::GetMtu (uint32_t i) const
 bool 
 Ipv4L3Protocol::IsUp (uint32_t i) const
 {
-  NS_LOG_FUNCTION (this << i);
   Ptr<Ipv4Interface> interface = GetInterface (i);
   return interface->IsUp ();
 }
@@ -1014,7 +1012,6 @@ Ipv4L3Protocol::SetForwarding (uint32_t i, bool val)
 Ptr<NetDevice>
 Ipv4L3Protocol::GetNetDevice (uint32_t i)
 {
-  NS_LOG_FUNCTION (this << i);
   return GetInterface (i)-> GetDevice ();
 }
 
