@@ -100,6 +100,7 @@ NscTcpSocketImpl::NscTcpSocketImpl(const NscTcpSocketImpl& sock)
     m_connected (sock.m_connected),
     m_state (sock.m_state),
     m_closeOnEmpty (sock.m_closeOnEmpty),
+    m_txBufferSize (sock.m_txBufferSize),
     m_segmentSize (sock.m_segmentSize),
     m_rxWindowSize (sock.m_rxWindowSize),
     m_advertisedWindowSize (sock.m_advertisedWindowSize),
@@ -465,7 +466,8 @@ NscTcpSocketImpl::GetRxAvailable (void) const
 }
 
 void
-NscTcpSocketImpl::ForwardUp (Ptr<Packet> packet, Ipv4Address saddr, Ipv4Address daddr, uint16_t port)
+NscTcpSocketImpl::ForwardUp (Ptr<Packet> packet, Ipv4Header header, uint16_t port,
+                             Ptr<Ipv4Interface> incomingInterface)
 {
   NSCWakeup();
 }
@@ -620,7 +622,12 @@ bool NscTcpSocketImpl::SendPendingData (void)
     NS_ASSERT (size > 0);
 
     m_errno = ERROR_NOTERROR;
-    ret = m_nscTcpSocket->send_data((const char *)p->PeekData (), size);
+
+    uint8_t *buf = new uint8_t[size];
+    p->CopyData (buf, size);
+    ret = m_nscTcpSocket->send_data((const char *)buf, size);
+    delete[] buf;
+
     if (ret <= 0)
       {
         break;
@@ -817,4 +824,20 @@ NscTcpSocketImpl::GetNativeNs3Errno(int error) const
   return ERROR_INVAL;
 }
 
+bool
+NscTcpSocketImpl::SetAllowBroadcast (bool allowBroadcast)
+{
+  if (allowBroadcast)
+    {
+      return false;
+    }
+  return true;
+}
+
+bool
+NscTcpSocketImpl::GetAllowBroadcast () const
+{
+  return false;
+}
+
 }//namespace ns3
