@@ -35,6 +35,8 @@ class Socket;
 class Ipv4Route;
 class Ipv4EndPointDemux;
 class Ipv4EndPoint;
+class UdpSocketImpl;
+
 /**
  * \ingroup udp
  * \brief Implementation of the UDP protocol
@@ -84,14 +86,12 @@ public:
   /**
    * \brief Receive a packet up the protocol stack
    * \param p The Packet to dump the contents into
-   * \param source The source's Ipv4Address
-   * \param destination The destinations Ipv4Address
+   * \param header IPv4 Header information
    * \param interface the interface from which the packet is coming.
    */
   // inherited from Ipv4L4Protocol
   virtual enum Ipv4L4Protocol::RxStatus Receive(Ptr<Packet> p, 
-                                                Ipv4Address const &source,
-                                                Ipv4Address const &destination,
+                                                Ipv4Header const &header,
                                                 Ptr<Ipv4Interface> interface);
 
   /**
@@ -119,6 +119,9 @@ protected:
 private:
   Ptr<Node> m_node;
   Ipv4EndPointDemux *m_endPoints;
+  UdpL4Protocol (const UdpL4Protocol &o);
+  UdpL4Protocol &operator = (const UdpL4Protocol &o);
+  std::vector<Ptr<UdpSocketImpl> > m_sockets;
 };
 
 }; // namespace ns3
