@@ -33,6 +33,8 @@ NS_LOG_COMPONENT_DEFINE ("PacketSocket");
 
 namespace ns3 {
 
+NS_OBJECT_ENSURE_REGISTERED (PacketSocket);
+
 TypeId
 PacketSocket::GetTypeId (void)
 {
@@ -185,6 +187,10 @@ PacketSocket::Close(void)
       m_errno = ERROR_BADF;
       return -1;
     }
+  else if (m_state == STATE_BOUND || m_state == STATE_CONNECTED)
+    {
+      m_node->UnregisterProtocolHandler (MakeCallback (&PacketSocket::ForwardUp, this));
+    }
   m_state = STATE_CLOSED;
   m_shutdownSend = true;
   m_shutdownRecv = true;
@@ -457,4 +463,20 @@ PacketSocket::GetSockName (Address &address) const
   return 0;
 }
 
+bool
+PacketSocket::SetAllowBroadcast (bool allowBroadcast)
+{
+  if (allowBroadcast)
+    {
+      return false;
+    }
+  return true;
+}
+
+bool
+PacketSocket::GetAllowBroadcast () const
+{
+  return false;
+}
+
 }//namespace ns3
