@@ -222,6 +222,20 @@ Ipv4StaticRouting::LookupStatic (Ipv4Address dest, Ptr<NetDevice> oif)
   Ptr<Ipv4Route> rtentry = 0;
   uint16_t longest_mask = 0;
   uint32_t shortest_metric = 0xffffffff;
+  /* when sending on local multicast, there have to be interface specified */
+  if (dest.IsLocalMulticast ())
+    {
+      NS_ASSERT_MSG (oif, "Try to send on link-local multicast address, and no interface index is given!");
+
+      rtentry = Create<Ipv4Route> ();
+      rtentry->SetDestination (dest);
+      rtentry->SetGateway (Ipv4Address::GetZero ());
+      rtentry->SetOutputDevice (oif);
+      rtentry->SetSource (m_ipv4->GetAddress (oif->GetIfIndex (), 0).GetLocal ());
+      return rtentry;
+    }
+
+
   for (NetworkRoutesI i = m_networkRoutes.begin (); 
        i != m_networkRoutes.end (); 
        i++) 
@@ -594,7 +608,8 @@ Ipv4StaticRouting::NotifyInterfaceUp (uint32_t i)
   for (uint32_t j = 0; j < m_ipv4->GetNAddresses (i); j++)
     {
       if (m_ipv4->GetAddress (i,j).GetLocal () != Ipv4Address () &&
-          m_ipv4->GetAddress (i,j).GetMask () != Ipv4Mask ())
+          m_ipv4->GetAddress (i,j).GetMask () != Ipv4Mask () &&
+          m_ipv4->GetAddress (i,j).GetMask () != Ipv4Mask::GetOnes())
         {
           AddNetworkRouteTo (m_ipv4->GetAddress (i,j).GetLocal ().CombineMask (m_ipv4->GetAddress (i,j).GetMask ()),
                              m_ipv4->GetAddress (i,j).GetMask (), i);
