@@ -153,10 +153,16 @@ Ns3TcpInteroperabilityTestCase::Ipv4L3Tx (std::string context, Ptr<const Packet>
       //
       Time tNow = Simulator::Now ();
       int64_t tMicroSeconds = tNow.GetMicroSeconds ();
+
+      uint32_t size = p->GetSize ();
+      uint8_t *buf = new uint8_t[size];
+      p->CopyData (buf, size);
+
       m_pcapFile.Write (uint32_t (tMicroSeconds / 1000000), 
                         uint32_t (tMicroSeconds % 1000000), 
-                        p->PeekData(), 
-                        p->GetSize ());
+                        buf, 
+                        size);
+      delete [] buf;
     }
   else
     {
@@ -168,10 +174,13 @@ Ns3TcpInteroperabilityTestCase::Ipv4L3Tx (std::string context, Ptr<const Packet>
       uint32_t tsSec, tsUsec, inclLen, origLen, readLen;
       m_pcapFile.Read (expected, sizeof(expected), tsSec, tsUsec, inclLen, origLen, readLen);
 
-      uint8_t const *actual = p->PeekData();
+      uint8_t *actual = new uint8_t[readLen];
+      p->CopyData (actual, readLen);
 
       uint32_t result = memcmp(actual, expected, readLen);
 
+      delete [] actual;
+
       //
       // Avoid streams of errors -- only report the first.
       //
