@@ -11,6 +11,8 @@
 #include <set>
 #include <exception>
 
+#include <stdint.h>
+
 // Deprecation warnings look ugly and confusing; better to just
 // disable them and change this macro when we want to specifically
 // test them.
@@ -177,7 +179,11 @@ void delete_stored_zbr (void);
 
 
 class Foobar
+// -#- allow_subclassing=true -#-
 {
+    Foobar (const Foobar &);
+    Foobar& operator= (const Foobar &);
+    
 public:
     static int instance_count;
 
@@ -425,22 +431,25 @@ public:
 
     // custodian/ward tests
 
-    // -#- @return(custodian=0) -#-
+    // -#- @return(custodian=0, reference_existing_object=true) -#-
     Foobar* get_foobar_with_self_as_custodian () {
         if (m_foobar == NULL) {
             m_foobar = new Foobar;
         }
         return m_foobar;
     }
-    // -#- @return(custodian=1); @other(transfer_ownership=false) -#-
+    // -#- @return(custodian=1, reference_existing_object=true); @other(transfer_ownership=false) -#-
     Foobar* get_foobar_with_other_as_custodian (SomeObject *other) {
         return other->get_foobar_with_self_as_custodian ();
     }
-    // -#- @foobar(custodian=0) -#-
+    // -#- @foobar(custodian=0, transfer_ownership=True) -#-
     void set_foobar_with_self_as_custodian (Foobar *foobar) {
         delete m_foobar;
         m_foobar = foobar;
     }
+
+protected:
+    std::string protected_method_that_is_not_virtual (std::string arg) const;
 };
 
 
@@ -492,6 +501,9 @@ namespace xpto
     FooType get_foo_type ();
     void set_foo_type (FooType type);
 
+    // -#- @type(direction=inout) -#-
+    void set_foo_type_ptr (FooType *type);
+
     // -#- @type(direction=inout) -#-
     void set_foo_type_inout (FooType &type);
 
@@ -500,14 +512,14 @@ namespace xpto
     std::string get_foo_datum(FooXpto const &foo);
 }
 
-// -#- @return(custodian=1); @other(transfer_ownership=false) -#-
+// -#- @return(custodian=1, reference_existing_object=true); @other(transfer_ownership=false) -#-
 Foobar* get_foobar_with_other_as_custodian(SomeObject *other);
 
 // -#- @return(caller_owns_return=true) -#-
 Foobar* create_new_foobar();
-// -#- @foobar(custodian=2); @other(transfer_ownership=false) -#-
+// -#- @foobar(custodian=2, transfer_ownership=true); @other(transfer_ownership=false) -#-
 void set_foobar_with_other_as_custodian(Foobar *foobar, SomeObject *other);
-// -#- @foobar(custodian=-1); @return(caller_owns_return=true) -#-
+// -#- @foobar(custodian=-1, transfer_ownership=true); @return(caller_owns_return=true) -#-
 SomeObject * set_foobar_with_return_as_custodian(Foobar *foobar);
 
 class SingletonClass
@@ -787,8 +799,14 @@ public:
     
     std::set<float> m_floatSet;
 
-    TestContainer () { m_floatSet.insert (1.0); m_floatSet.insert (2.0); m_floatSet.insert (3.0); }
-    virtual ~TestContainer () {}
+    TestContainer () : m_vec (NULL) {
+        m_floatSet.insert (1.0);
+        m_floatSet.insert (2.0);
+        m_floatSet.insert (3.0);
+    }
+    virtual ~TestContainer () {
+        delete m_vec;
+    }
 
     virtual SimpleStructList get_simple_list ();
     virtual int set_simple_list (SimpleStructList list);
@@ -910,7 +928,7 @@ inline Tupl & operator += (Tupl &a, Tupl const &b)
     return a;
 }
 
-inline Tupl & operator += (Tupl &a, double b)
+inline Tupl & operator += (Tupl &a, int b)
 {
     a.x += b;
     a.y += b;
@@ -1067,6 +1085,8 @@ public:
     // returns 1/x, raises DomainError if x == 0
     double my_inverse_method (double x) throw (DomainError);
     double my_inverse_method2 (double x) throw (std::exception);
+
+    virtual int throw_error () const throw (std::exception);
 };
 
 
@@ -1115,4 +1135,67 @@ static inline std::string __property_inst()
 }
 
 
+
+class Box
+{
+    Foobar m_foobar;
+
+public:
+    static int instance_count;
+
+    // -#- return_internal_reference=true -#-
+    Foobar *m_internalFoobar;
+
+    Box () { ++instance_count; m_internalFoobar = &m_foobar; }
+    virtual ~Box () { --instance_count;}
+
+    // -#- @return(reference_existing_object=true) -#-
+    Foobar* getFoobarInternalPtr () { return &m_foobar; }
+    
+    // -#- @return(reference_existing_object=true) -#-
+    Foobar& getFoobarInternalRef () { return m_foobar; }
+
+    // -#- @return(return_internal_reference=true) -#-
+    Foobar* getFoobarInternalPtr2 () { return &m_foobar; }
+    
+    // -#- @return(return_internal_reference=true) -#-
+    Foobar& getFoobarInternalRef2 () { return m_foobar; }
+
+};
+
+
+// multiple inheritance
+class MIRoot
+{
+public:
+    MIRoot () {}
+    int root_method () const { return -1; } 
+};
+
+
+class MIBase1 : public virtual MIRoot
+{
+    int m_value;
+public:
+    MIBase1 () : m_value (1) {}
+    int base1_method () const { return m_value; } 
+};
+
+class MIBase2 : public virtual MIRoot
+{
+    int m_value;
+public:
+    MIBase2 ()  : m_value (2) {}
+    int base2_method () const { return m_value; } 
+};
+
+class MIMixed : public MIBase1, public MIBase2
+{
+public:
+    MIMixed () {}
+    int mixed_method () const { return 3; } 
+};
+    
+
+
 #endif 	    /* !FOO_H_ */
