@@ -47,7 +47,7 @@ def my_module_gen(out_file):
     Zoo.add_method('get_datum', ReturnValue.new('std::string'), [])
     Zoo.implicitly_converts_to(Foo)
 
-    Foobar = mod.add_class('Foobar')
+    Foobar = mod.add_class('Foobar', allow_subclassing=True)
     Foobar.add_static_attribute('instance_count', ReturnValue.new('int'))
 
 
@@ -211,24 +211,28 @@ int %s::custom_method_added_by_a_hook(int x)
 
     ## custodian/ward tests
     SomeObject.add_method('get_foobar_with_self_as_custodian',
-                          ReturnValue.new('Foobar*', custodian=0), [])
+                          ReturnValue.new('Foobar*', custodian=0, reference_existing_object=True), [])
     SomeObject.add_method('get_foobar_with_other_as_custodian',
-                          ReturnValue.new('Foobar*', custodian=1),
+                          ReturnValue.new('Foobar*', custodian=1, reference_existing_object=True),
                           [Parameter.new('SomeObject*', 'other', transfer_ownership=False)])
     SomeObject.add_method('set_foobar_with_self_as_custodian', ReturnValue.new('void'),
-                          [Parameter.new('Foobar*', 'foobar', custodian=0)])
+                          [Parameter.new('Foobar*', 'foobar',
+                                         transfer_ownership=True, custodian=0)])
 
-    mod.add_function('get_foobar_with_other_as_custodian', ReturnValue.new('Foobar*', custodian=1),
+    mod.add_function('get_foobar_with_other_as_custodian',
+                     ReturnValue.new('Foobar*', custodian=1, reference_existing_object=True),
                      [Parameter.new('SomeObject*', 'other', transfer_ownership=False)])
 
     mod.add_function('create_new_foobar', ReturnValue.new('Foobar*', caller_owns_return=True), [])
 
     mod.add_function('set_foobar_with_other_as_custodian', ReturnValue.new('void'),
-                     [Parameter.new('Foobar*', 'foobar', custodian=2),
+                     [Parameter.new('Foobar*', 'foobar', transfer_ownership=True, custodian=2),
                       Parameter.new('SomeObject*', 'other', transfer_ownership=False)])
 
-    mod.add_function('set_foobar_with_return_as_custodian', ReturnValue.new('SomeObject*', caller_owns_return=True),
-                     [Parameter.new('Foobar*', 'foobar', custodian=-1)])
+    mod.add_function('set_foobar_with_return_as_custodian',
+                     ReturnValue.new('SomeObject*', caller_owns_return=True),
+                     [Parameter.new('Foobar*', 'foobar',
+                                    transfer_ownership=True, custodian=-1)])
 
 
     ## get/set recfcounted object Zbr
@@ -254,6 +258,11 @@ int %s::custom_method_added_by_a_hook(int x)
                           [Parameter.new('double', 'from_float')],
                           custom_name="get_int")
 
+    # Bug #508577
+    SomeObject.add_method('protected_method_that_is_not_virtual',
+                          ReturnValue.new('std::string'),
+                          [Parameter.new('std::string', 'arg')],
+                          is_const=True, visibility='protected')
 
     mod.add_function('store_some_object', ReturnValue.new('void'),
                      [Parameter.new('SomeObject*', 'obj', transfer_ownership=True)])
@@ -271,6 +280,8 @@ int %s::custom_method_added_by_a_hook(int x)
     xpto.add_function('set_foo_type', ReturnValue.new('void'), [Parameter.new("FooType", 'type')])
     xpto.add_function('set_foo_type_inout', ReturnValue.new('void'),
                       [Parameter.new("FooType&", 'type', direction=Parameter.DIRECTION_INOUT)])
+    xpto.add_function('set_foo_type_ptr', ReturnValue.new('void'),
+                      [Parameter.new("FooType*", 'type', direction=Parameter.DIRECTION_INOUT)])
 
 
     xpto_SomeClass = xpto.add_class('SomeClass', docstring="This is the docstring for SomeClass")
@@ -467,7 +478,7 @@ int %s::custom_method_added_by_a_hook(int x)
 
     Tupl.add_unary_numeric_operator('-')
 
-    Tupl.add_inplace_numeric_operator('+=', right='double')
+    Tupl.add_inplace_numeric_operator('+=', right='int')
 
 
     ManipulatedObject = mod.add_class('ManipulatedObject')
@@ -505,7 +516,7 @@ int %s::custom_method_added_by_a_hook(int x)
     mod.add_function('my_inverse_func', 'double', [Parameter.new('double', 'x')],
                      throw=[DomainError])
 
-    ClassThatThrows = mod.add_class('ClassThatThrows')
+    ClassThatThrows = mod.add_class('ClassThatThrows', allow_subclassing=True)
     ClassThatThrows.add_constructor([Parameter.new('double', 'x')], throw=[DomainError])
     ClassThatThrows.add_method('my_inverse_method', 'double', [Parameter.new('double', 'x')],
                                throw=[DomainError])
@@ -516,6 +527,8 @@ int %s::custom_method_added_by_a_hook(int x)
     ClassThatThrows.add_method('my_inverse_method2', 'double', [Parameter.new('double', 'x')],
                                throw=[std_exception])
 
+    ClassThatThrows.add_method('throw_error', 'int', [], throw=[std_exception], is_const=True, is_virtual=True)
+
     # https://bugs.launchpad.net/pybindgen/+bug/450255
     ProtectedConstructor = mod.add_class('ProtectedConstructor')
     ProtectedConstructor.add_constructor([])
@@ -523,6 +536,36 @@ int %s::custom_method_added_by_a_hook(int x)
 
     # https://bugs.launchpad.net/pybindgen/+bug/455689
     property_std_string = mod.add_struct('property', template_parameters=['std::string'])
+
+
+
+    Box = mod.add_class('Box')
+    Box.add_constructor([])
+    Box.add_static_attribute('instance_count', ReturnValue.new('int'))
+    Box.add_method('getFoobarInternalPtr', ReturnValue.new('Foobar*', reference_existing_object=True), [])
+    Box.add_method('getFoobarInternalRef', ReturnValue.new('Foobar&', reference_existing_object=True), [])
+    Box.add_method('getFoobarInternalPtr2', ReturnValue.new('Foobar*', return_internal_reference=True), [])
+    Box.add_method('getFoobarInternalRef2', ReturnValue.new('Foobar&', return_internal_reference=True), [])
+    Box.add_instance_attribute('m_internalFoobar', ReturnValue.new('Foobar*', reference_existing_object=True))
+
+
+    # multiple inheritance
+    MIRoot = mod.add_class('MIRoot')
+    MIRoot.add_constructor([])
+    MIRoot.add_method('root_method', 'int', [], is_const=True)
+    
+    MIBase1 = mod.add_class('MIBase1', parent=MIRoot)
+    MIBase1.add_constructor([])
+    MIBase1.add_method('base1_method', 'int', [], is_const=True)
+
+    MIBase2 = mod.add_class('MIBase2', parent=MIRoot)
+    MIBase2.add_constructor([])
+    MIBase2.add_method('base2_method', 'int', [], is_const=True)
+
+    MIMixed = mod.add_class('MIMixed', parent=[MIBase1, MIBase2])
+    MIMixed.add_constructor([])
+    MIMixed.add_method('mixed_method', 'int', [], is_const=True)
+
     
     #### --- error handler ---
     class MyErrorHandler(pybindgen.settings.ErrorHandler):
