@@ -199,7 +199,7 @@ class TestFoo(unittest.TestCase):
 
     def test_virtual_subclass(self):
         class Test(foo.SomeObject):
-            def _get_prefix(self):
+            def get_prefix(self):
                 return "yyy"
 
         t = Test("xxx")
@@ -207,8 +207,8 @@ class TestFoo(unittest.TestCase):
 
     def test_virtual_with_chaining_to_parent_class(self):
         class Test(foo.SomeObject):
-            def _get_prefix(self):
-                prefix = super(Test, self)._get_prefix()
+            def get_prefix(self):
+                prefix = super(Test, self).get_prefix()
                 return prefix + "yyy"
 
         t = Test("xxx")
@@ -262,8 +262,8 @@ class TestFoo(unittest.TestCase):
             def __init__(self, prefix, extra_prefix):
                 super(Test, self).__init__(prefix)
                 self.extra_prefix = extra_prefix
-            def _get_prefix(self):
-                prefix = super(Test, self)._get_prefix()
+            def get_prefix(self):
+                prefix = super(Test, self).get_prefix()
                 return prefix + self.extra_prefix
         while gc.collect():
             pass
@@ -523,8 +523,8 @@ class TestFoo(unittest.TestCase):
             def __init__(self, prefix, extra_prefix):
                 super(Test, self).__init__(prefix)
                 self.extra_prefix = extra_prefix
-            def _get_prefix_with_foo_value(self, fooval):
-                prefix = super(Test, self)._get_prefix_with_foo_value(fooval)
+            def get_prefix_with_foo_value(self, fooval):
+                prefix = super(Test, self).get_prefix_with_foo_value(fooval)
                 return prefix + self.extra_prefix + fooval.get_datum()
 
         t = Test("123", "456")
@@ -537,8 +537,8 @@ class TestFoo(unittest.TestCase):
             def __init__(self, prefix, extra_prefix):
                 super(Test, self).__init__(prefix)
                 self.extra_prefix = extra_prefix
-            def _get_prefix_with_foo_ref(self, fooval):
-                prefix = super(Test, self)._get_prefix_with_foo_ref(fooval)
+            def get_prefix_with_foo_ref(self, fooval):
+                prefix = super(Test, self).get_prefix_with_foo_ref(fooval)
                 return prefix + self.extra_prefix + fooval.get_datum()
 
         t = Test("123", "456")
@@ -552,8 +552,8 @@ class TestFoo(unittest.TestCase):
             def __init__(self, prefix, extra_prefix):
                 super(Test, self).__init__(prefix)
                 self.extra_prefix = extra_prefix
-            def _get_prefix_with_foo_ptr(self, fooval):
-                prefix = super(Test, self)._get_prefix_with_foo_ptr(fooval)
+            def get_prefix_with_foo_ptr(self, fooval):
+                prefix = super(Test, self).get_prefix_with_foo_ptr(fooval)
                 return prefix + self.extra_prefix + fooval.get_datum()
 
         t = Test("123", "456")
@@ -597,9 +597,13 @@ class TestFoo(unittest.TestCase):
     def test_enum(self):
         foo.xpto.set_foo_type(foo.xpto.FOO_TYPE_BBB)
         self.assertEqual(foo.xpto.get_foo_type(), foo.xpto.FOO_TYPE_BBB)
+
         old = foo.xpto.set_foo_type_inout(foo.xpto.FOO_TYPE_CCC)
         self.assertEqual(old, foo.xpto.FOO_TYPE_BBB)
 
+        old = foo.xpto.set_foo_type_ptr(foo.xpto.FOO_TYPE_AAA)
+        self.assertEqual(old, foo.xpto.FOO_TYPE_CCC)
+
     def test_virtual_overload(self):
         ## first test the plain object
         obj = foo.SomeObject("")
@@ -632,7 +636,7 @@ class TestFoo(unittest.TestCase):
 
     def test_private_virtual(self):
         class Class(foo.AbstractBaseClass2):
-            def _private_virtual(self, x):
+            def private_virtual(self, x):
                 return x*x
         c = Class()
         x = c.invoke_private_virtual(2)
@@ -640,10 +644,10 @@ class TestFoo(unittest.TestCase):
 
     def test_protected_virtual(self):
         class Class(foo.AbstractBaseClass2):
-            def _private_virtual(self, x):
+            def private_virtual(self, x):
                 return x*x
-            def _protected_virtual(self, x):
-                y = super(Class, self)._protected_virtual(x)
+            def protected_virtual(self, x):
+                y = super(Class, self).protected_virtual(x)
                 return y*y
         c = Class()
         x = c.invoke_protected_virtual(2)
@@ -651,7 +655,7 @@ class TestFoo(unittest.TestCase):
 
     def test_protected_pure_virtual(self):
         class Class(foo.AbstractBaseClass2):
-            def _protected_pure_virtual(self, x):
+            def protected_pure_virtual(self, x):
                 return x*x+1
         c = Class()
         x = c.invoke_protected_pure_virtual(2)
@@ -662,7 +666,7 @@ class TestFoo(unittest.TestCase):
             def __init__(self, y):
                 super(Test, self).__init__("foo")
                 self.y = y
-            def _get_int(self, x):
+            def get_int(self, x):
                 return getattr(self, 'y', 0) + x
                 
         while gc.collect():
@@ -851,7 +855,7 @@ class TestFoo(unittest.TestCase):
                 super(MyTestContainer, self).__init__()
                 self.list_that_was_set = None
 
-            def _get_simple_list(self):
+            def get_simple_list(self):
                 l = []
                 for i in range(5):
                     simple = foo.simple_struct_t()
@@ -860,7 +864,7 @@ class TestFoo(unittest.TestCase):
                 #container = foo.SimpleStructList(l)
                 return l
 
-            def _set_simple_list(self, container):
+            def set_simple_list(self, container):
                 self.list_that_was_set = container
                 return sum([s.xpto for s in container])
 
@@ -954,6 +958,9 @@ class TestFoo(unittest.TestCase):
         
 
     def test_refcounting_v2(self):
+        while gc.collect():
+            pass
+
         zbr_count_before = foo.Zbr.instance_count
 
         obj = foo.SomeObject("")
@@ -1134,7 +1141,7 @@ class TestFoo(unittest.TestCase):
 
     def test_virtual_method_reference_parameter(self):
         class MyReferenceManipulator(foo.ReferenceManipulator):
-            def _do_manipulate_object(self, obj):
+            def do_manipulate_object(self, obj):
                 obj.SetValue(12345)
         manip = MyReferenceManipulator()
         retval = manip.manipulate_object()
@@ -1215,5 +1222,159 @@ class TestFoo(unittest.TestCase):
     def test_bug455689(self):
         p = foo.Property__StdString()
 
+    def test_reference_existing_object_ptr(self):
+        while gc.collect():
+            pass
+        Foobar_count1 = foo.Foobar.instance_count
+        box = foo.Box()
+        self.assertEqual(foo.Foobar.instance_count, Foobar_count1+1)
+
+        f1 = box.getFoobarInternalPtr()
+        self.assertEqual(foo.Foobar.instance_count, Foobar_count1+1)
+        f2 = box.getFoobarInternalPtr()
+        self.assertEqual(foo.Foobar.instance_count, Foobar_count1+1)
+        self.assert_(f2 is f1)
+        
+        del f1, f2, box
+        
+        while gc.collect():
+            pass
+
+        self.assertEqual(foo.Foobar.instance_count, Foobar_count1)
+
+    def test_reference_existing_object_ptr_attribute(self):
+        while gc.collect():
+            pass
+        Foobar_count1 = foo.Foobar.instance_count
+        box = foo.Box()
+        self.assertEqual(foo.Foobar.instance_count, Foobar_count1+1)
+
+        f1 = box.m_internalFoobar
+        self.assertEqual(foo.Foobar.instance_count, Foobar_count1+1)
+        f2 = box.m_internalFoobar
+        self.assertEqual(foo.Foobar.instance_count, Foobar_count1+1)
+        self.assert_(f2 is f1)
+        
+        del f1, f2, box
+        
+        while gc.collect():
+            pass
+
+        self.assertEqual(foo.Foobar.instance_count, Foobar_count1)
+        
+
+    def test_reference_existing_object_ref(self):
+        while gc.collect():
+            pass
+        Foobar_count1 = foo.Foobar.instance_count
+        box = foo.Box()
+        self.assertEqual(foo.Foobar.instance_count, Foobar_count1+1)
+
+        f1 = box.getFoobarInternalRef()
+        self.assertEqual(foo.Foobar.instance_count, Foobar_count1+1)
+        f2 = box.getFoobarInternalRef()
+        self.assertEqual(foo.Foobar.instance_count, Foobar_count1+1)
+        self.assert_(f2 is f1)
+        
+        del f1, f2, box
+        
+        while gc.collect():
+            pass
+
+        self.assertEqual(foo.Foobar.instance_count, Foobar_count1)
+
+
+    def test_reference_existing_object_ptr2(self):
+        while gc.collect():
+            pass
+        Foobar_count1 = foo.Foobar.instance_count
+        Box_count1 = foo.Box.instance_count;
+
+        box = foo.Box()
+        self.assertEqual(foo.Box.instance_count, Box_count1 + 1)
+        self.assertEqual(foo.Foobar.instance_count, Foobar_count1+1)
+
+        f1 = box.getFoobarInternalPtr2()
+        self.assertEqual(foo.Foobar.instance_count, Foobar_count1+1)
+        f2 = box.getFoobarInternalPtr2()
+        self.assertEqual(foo.Foobar.instance_count, Foobar_count1+1)
+        self.assert_(f2 is f1)
+        
+        del f2, box
+        while gc.collect():
+            pass
+
+        # f1 is still alive, so box should still exist, in spite of having been locally unreferenced
+        self.assertEqual(foo.Box.instance_count, Box_count1 + 1)
+        self.assertEqual(foo.Foobar.instance_count, Foobar_count1 + 1)
+
+        # delete f1, it should cause box to be freeable
+        del f1
+        while gc.collect():
+            pass
+
+        self.assertEqual(foo.Foobar.instance_count, Foobar_count1)
+        self.assertEqual(foo.Box.instance_count, Box_count1)
+        
+
+    def test_reference_existing_object_ref2(self):
+        while gc.collect():
+            pass
+        Foobar_count1 = foo.Foobar.instance_count
+        Box_count1 = foo.Box.instance_count;
+
+        box = foo.Box()
+        self.assertEqual(foo.Box.instance_count, Box_count1 + 1)
+        self.assertEqual(foo.Foobar.instance_count, Foobar_count1+1)
+
+        f1 = box.getFoobarInternalRef2()
+        self.assertEqual(foo.Foobar.instance_count, Foobar_count1+1)
+        f2 = box.getFoobarInternalRef2()
+        self.assertEqual(foo.Foobar.instance_count, Foobar_count1+1)
+        self.assert_(f2 is f1)
+        
+        del f2, box
+        while gc.collect():
+            pass
+
+        # f1 is still alive, so box should still exist, in spite of having been locally unreferenced
+        self.assertEqual(foo.Box.instance_count, Box_count1 + 1)
+        self.assertEqual(foo.Foobar.instance_count, Foobar_count1 + 1)
+
+        # delete f1, it should cause box to be freeable
+        del f1
+        while gc.collect():
+            pass
+
+        self.assertEqual(foo.Foobar.instance_count, Foobar_count1)
+        self.assertEqual(foo.Box.instance_count, Box_count1)
+
+    def test_protected_method_no_subclassing(self):
+        some = foo.SomeObject("xxx")
+        self.assert_(hasattr(some, "protected_method_that_is_not_virtual"))
+        self.assertRaises(TypeError, some.protected_method_that_is_not_virtual, "aax")
+        del some
+
+    def test_protected_method_with_subclassing(self):
+        class Test(foo.SomeObject):
+            def __init__(self, prefix):
+                super(Test, self).__init__(prefix)
+        some = Test("foo")
+        v = some.protected_method_that_is_not_virtual("ajax")
+        self.assertEqual(v, "fooajax")
+        del some
+
+    def test_multiple_inheritance(self):
+        mi = foo.MIMixed()
+        self.assert_(hasattr(mi, "mixed_method"))
+        self.assert_(hasattr(mi, "base1_method"))
+        self.assert_(hasattr(mi, "base2_method"))
+        self.assert_(hasattr(mi, "root_method"))
+        self.assertEqual(mi.root_method(), -1)
+        self.assertEqual(mi.base1_method(), 1)
+        self.assertEqual(mi.base2_method(), 2)
+        self.assertEqual(mi.mixed_method(), 3)
+
+
 if __name__ == '__main__':
     unittest.main()
